# This script will process my raw Biomass data from the 2023 GH experiment
# in prep for model analysis for my GH-Meso manuscript

# Load req'd packages
library(tidyverse) # for cleaning

# Load data ----
# Set your working directory
setwd()
# Load "Greenhouse_Biomass.csv" file
Bio <- read.csv("Greenhouse_Biomass.csv", header = T)
head(Bio)

# Remove NAs
# NAs indicate that a seedling was recorded in my percent cover data, but were
# not found during harvest; here I remove them
Bio[rowSums(is.na(Bio)) > 0, ]
Bio <- na.omit(Bio)

# Load treatment info
Tmt <- read.csv("Greenhouse_Treatment_Locations.csv", header = T)
head(Tmt)

Tmt <- Tmt %>% 
  rename("Bucket" = "ï..Number")

Bio <- Bio %>% 
  full_join(Tmt, by = "Bucket") 
# Full join to keep all treatments, even if the treatment had zero growth
# Once we sum our native & invasive biomass, we would change the NAs to 0

head(Bio)
count(Bio[rowSums(is.na(Bio)) > 0, ]) 
# 14 treatments with zero growth, which we want to change from NA to 0

# Check that we have correct number of treatments per native / invasive

Bio <- Bio %>% 
  mutate(Species = factor(case_when(
    Species == "EPCI" ~ "E. ciliatum",
    Species == "CAMI" ~ "C. minor",
    Species == "EUMA" ~ "E. maculatum",
    Species == "EUOC" ~ "E. occidentalis",
    Species == "GRSQ" ~ "G. squarrosa",
    Species == "RUMA" ~ "R. maritimus",
    Species == "SOCA" ~ "S. canadensis",
    Species == "SYCI" ~ "S. ciliatum",
    Species == "VEHA" ~ "V. hastata",
    Species == "DISP" ~ "D. spicata",
    Species == "BOMA" ~ "B. maritimus",
    Species == "SCAM" ~ "S. americanus",
    Species == "SCAC" ~ "S. acutus",
    Species == "ELPA" ~ "E. palustris",
    Species == "PUNU" ~ "P. nuttalliana",
    Species == "MUAS" ~ "M. asperifolia",
    Species == "JUAR" ~ "J. arcticus",
    Species == "CAPR" ~ "C. praegracilis",
    Species == "PHAU" ~ "P. australis",
    Species == NA ~ NA,
    TRUE ~ Species)),
    Status = factor(case_when(
      Species %in% c("E. ciliatum", "C. minor", "E. maculatum", "E. occidentalis",
                     "G. squarrosa", "R. maritimus", "S. canadensis", "S. ciliatum", 
                     "V. hastata", 
                     "D. spicata", "B. maritimus", "S. americanus", "S. acutus",
                     "E. palustris", "P. nuttalliana", "M. asperifolia",
                     "J. arcticus", "C. praegracilis", 
                     "Unknown 2", "Unknown 8") ~ "Native",
      Species == "P. australis" ~ "Invasive",
      Species == NA ~ NA,
      TRUE ~ Species)))

head(Bio)

check_i <- Bio %>% 
  filter(Status == "Invasive")
table(check_i$Seed_Mix, check_i$Salinity, check_i$Water_Level, check_i$Status)
# so we don't have enough invasive observations in the gram-w-phau seed mix.

# do we have enough gram-w-phau rows?

check_i <- Bio %>% 
  group_by(Bucket, Status, Seed_Mix, Salinity, Water_Level) %>% 
  summarize(Total_Weight = sum(Weight)) %>% 
  filter(Seed_Mix == "GRAM-W-PHAU")
table(check_i$Bucket)

# each bucket here should have 2 observations (one native, one invasive)

Bio <- Bio %>% 
  filter(is.na(Status)) %>% 
  bind_rows(Bio) 

which(is.na(Bio), arr.ind = T) 
# Checking that rows are exact duplicates
Bio[c(1:14, 408:421), c(1:7, 10)]

Bio <- Bio %>% 
  mutate(Status = case_when(row_number() %in% 1:14 ~ "Native",
                            row_number() %in% 408:421 ~ "Invasive",
                            TRUE ~ Status),
         Weight = case_when(row_number() %in% c(1:14, 408:421) ~ 0,
                            TRUE ~ Weight),
         Units = case_when(row_number() %in% c(1:14, 408:421) ~ "g",
                           TRUE ~ Units))
Bio[c(1:14, 408:421), c(1:7, 10)]

# do we have enough gram-w-phau rows?

check_i <- Bio %>% 
  group_by(Bucket, Status, Seed_Mix, Salinity, Water_Level) %>% 
  summarize(Total_Weight = sum(Weight)) %>% 
  filter(Seed_Mix == "GRAM-W-PHAU")
table(check_i$Bucket) # no.

# We want to duplicate any rows where we don't have two observations 
# (native / invasive) for gram-w-phau, and forb-w-phau

check <- Bio %>% 
  group_by(Bucket, Status, Seed_Mix, Salinity, Water_Level) %>% 
  summarize(Total_Weight = sum(Weight)) %>% 
  filter(Seed_Mix == "GRAM-W-PHAU" | Seed_Mix == "FORB-W-PHAU")
table(check$Bucket)  

check <- Bio %>% 
  group_by(Bucket, Status, Seed_Mix, Salinity, Water_Level) %>% 
  summarize(Total_Weight = sum(Weight)) %>%
  group_by(Bucket, Seed_Mix, Salinity, Water_Level) %>% 
  mutate(my_cnt = n()) %>% 
  filter(!Seed_Mix %in% c("FORB", "PHAU", "GRAM")) %>%  # These seed mixes have 1 obs
  filter(my_cnt == 1) # 12 obs


# Now we want to change the status to its opposite value & make weights 0
check <- check %>%
  mutate(Total_Weight = 0,
         Status = ifelse(Status == "Native", "Invasive", "Native"),
         Units = "g",
         Notes = NA,
         Species = NA
  ) %>% 
  rename(Weight = Total_Weight) %>% 
  select(-my_cnt)

# Match columns with Bio, then add on
Bio <- Bio %>% 
  select(-ROW)

# bind extra 'check' df onto Bio

Bio <- Bio %>% 
  rbind(check)

# Double check output ----
check_i <- Bio %>% 
  group_by(Bucket, Status, Seed_Mix, Salinity, Water_Level) %>% 
  summarize(Total_Weight = sum(Weight)) %>% 
  filter(Seed_Mix == "GRAM-W-PHAU")
table(check_i$Bucket)

# Data wrangle ----

Bio <- Bio %>% 
  mutate(Weight = case_when(Units == "mg" ~ Weight / 1000,
                            Units == NA ~ NA,
                            TRUE ~ Weight), # Leave grams as is
         Units = case_when(Units == "mg" ~ "g",
                           Units == NA ~ NA,
                           TRUE ~ Units), # Leave grams as is
         Seed_Mix = case_when(Seed_Mix == "GRAM-W-PHAU" ~ "Graminoids with phragmites",
                              Seed_Mix == "FORB-W-PHAU" ~ "Forbs with phragmites",
                              Seed_Mix == "FORB" ~ "Forbs",
                              Seed_Mix == "GRAM" ~ "Graminoids",
                              Seed_Mix == "PHAU" ~ "Phragmites",
                              Seed_Mix == "CONTROL" ~ "Control"),
         Salinity = factor(case_when(Salinity == "FRESH" ~ "Fresh",
                                     Salinity == "MED" ~ "Medium",
                                     Salinity == "HIGH" ~ "High"),
                           levels = c("Fresh", "Medium", "High")),
         Water_Level = factor(case_when(Water_Level == "D" ~ "Moist",
                                        Water_Level == "S" ~ "Saturated"), 
                              levels = c("Saturated", "Moist")),
         Species = factor(case_when(
           Species == "EPCI" ~ "E. ciliatum",
           Species == "CAMI" ~ "C. minor",
           Species == "EUMA" ~ "E. maculatum",
           Species == "EUOC" ~ "E. occidentalis",
           Species == "GRSQ" ~ "G. squarrosa",
           Species == "RUMA" ~ "R. maritimus",
           Species == "SOCA" ~ "S. canadensis",
           Species == "SYCI" ~ "S. ciliatum",
           Species == "VEHA" ~ "V. hastata",
           Species == "DISP" ~ "D. spicata",
           Species == "BOMA" ~ "B. maritimus",
           Species == "SCAM" ~ "S. americanus",
           Species == "SCAC" ~ "S. acutus",
           Species == "ELPA" ~ "E. palustris",
           Species == "PUNU" ~ "P. nuttalliana",
           Species == "MUAS" ~ "M. asperifolia",
           Species == "JUAR" ~ "J. arcticus",
           Species == "CAPR" ~ "C. praegracilis",
           Species == "PHAU" ~ "P. australis",
           Species == NA ~ NA,
           TRUE ~ Species)),
         Status = factor(case_when(
           Species %in% c("E. ciliatum", "C. minor", "E. maculatum", "E. occidentalis",
                          "G. squarrosa", "R. maritimus", "S. canadensis", "S. ciliatum", 
                          "V. hastata", 
                          "D. spicata", "B. maritimus", "S. americanus", "S. acutus",
                          "E. palustris", "P. nuttalliana", "M. asperifolia",
                          "J. arcticus", "C. praegracilis", 
                          "Unknown 2", "Unknown 8") ~ "Native",
           Species == "P. australis" ~ "Invasive",
           Species == NA ~ NA,
           TRUE ~ Species)))

count(Bio[rowSums(is.na(Bio)) > 0, ]) 

# Change NAs to 0 ----
# Duplicate NA rows (so that we can set status to native OR invasive)
Bio <- Bio %>% 
  filter(is.na(Status)) %>% 
  bind_rows(Bio) 

which(is.na(Bio), arr.ind = T) 
# Checking that rows are exact duplicates
Bio[c(1:54, 448:473), c(1:7)]

Bio <- Bio %>% 
  mutate(Status = case_when(row_number() %in% 1:54 ~ "Native",
                            row_number() %in% 448:473 ~ "Invasive",
                            TRUE ~ Status),
         Weight = case_when(row_number() %in% c(1:54, 448:473) ~ 0,
                            TRUE ~ Weight),
         Units = case_when(row_number() %in% c(1:54, 448:473) ~ "g",
                           TRUE ~ Units))
Bio[c(1:54, 448:473), ]


Bio <- Bio %>% 
  filter(Status %in% c("Native", "Invasive"), # Remove non-seeded stuff
         Seed_Mix %in% c("Forbs", "Graminoids") & Status == "Native" |
           Seed_Mix %in% c("Phragmites") & Status == "Invasive" |
           Seed_Mix %in% c("Forbs with phragmites", "Graminoids with phragmites")
         & Status %in% c("Native", "Invasive")) 

Bio[which(is.na(Bio), arr.ind = T), ]
table(Bio$Seed_Mix, Bio$Salinity, Bio$Water_Level, Bio$Status)

# What are we missing for graminoids with p. australis?
check_i <- Bio %>% 
  group_by(Bucket, Seed_Mix, Salinity, Water_Level, Status) %>% 
  summarize(Total_Weight = sum(Weight)) %>% 
  filter(Status == "Invasive" & Seed_Mix == "Graminoids with phragmites")

check_n <- Bio %>% 
  group_by(Bucket, Seed_Mix, Salinity, Water_Level, Status) %>% 
  summarize(Total_Weight = sum(Weight)) %>% 
  filter(Status == "Native" & Seed_Mix == "Graminoids with phragmites")


table(check_n$Seed_Mix, check_n$Salinity, check_n$Water_Level, check_n$Status)
# good
table(check_i$Seed_Mix, check_i$Salinity, check_i$Water_Level, check_i$Status)
# good

## Check class of each column ----
sapply(Bio, class)
fac <- c("Bucket", "Species", "Seed_Mix", "Salinity", "Water_Level", "Status")
Bio[fac] <-lapply(Bio[fac], as.factor)
sapply(Bio, class)

## Check levels of each column ----
sapply(Bio, levels)

## Check unique values of non-factor columns ----
sapply(Bio, unique)

## Check min and max of weights ----
min(Bio$Weight)
max(Bio$Weight)

## Remove unnecessary cols ----
head(Bio)

Bio <- Bio %>% 
  select(-Notes)

head(Bio)

setwd("../Processed_Data")
save(Bio, file = "DF_Manuscript_Biomass.RData")



