# This script will clean the raw .csv files and prep them for analysis for the
# GH-Meso manuscript

# Load required packages
library(tidyverse) # For cleaning
library(lubridate) # for dates

# Set your working directory
setwd()
list.files()

# Load files ----
Forb <- read.csv("Greenhouse_Percent_Cover_Forbs.csv", header = T, skip = 1)
Gram <- read.csv("Greenhouse_Percent_Cover_Grams.csv", header = T, skip = 1)

# Change class ----
## Gram class ----
head(Gram)
num_cols <- colnames(Gram[, c(3:17)])
Gram[num_cols] <-lapply(Gram[num_cols], as.numeric)
Gram <- Gram %>% 
  mutate(Treatment_Number = factor(Treatment_Number))
unique(Gram$Treatment_Number)
Gram$Date <- mdy(Gram$Date)
sapply(Gram, class)

## Forb class ----
head(Forb)
num_cols <- colnames(Forb[, c(3:18)])
Forb[num_cols] <-lapply(Forb[num_cols], as.numeric)
Forb <- Forb %>% 
  mutate(Treatment_Number = factor(Treatment_Number))
Forb$Date <- mdy(Forb$Date)
sapply(Forb, class)

# Combine dataframes ----
# Find common names
intersect(names(Forb), names(Gram))

PC <- full_join(Forb, Gram, 
                by = c("Date", "Treatment_Number", "CAMI", "PHAU", "Unknown.3",
                       "Notes")) %>% 
  mutate(Treatment_Number = factor(Treatment_Number,
                                   levels = c("1-C", 2:33, "34-C", 35:59, "60-C",
                                              61:74, "75-C", 76:89, "90-C",
                                              91:125, "126-C")))
# Should have 504 total rows, 31 cols (19 + 18 - 6 in common)


# Check for any mistakes in dataframe ----

# Check for 4 monitoring dates per bucket
table(PC$Treatment_Number)

# Check for 126 buckets total
unique(PC$Treatment_Number)

# Make long ----
PC <- PC %>% 
  pivot_longer(cols = c(EPCI:Unknown.7, DISP:Unknown.8), 
               values_to = "Cover",
               names_to = "SPP")

# Check for unique species codes
unique(PC$SPP)

# Merge Percent Cover to midpoints, change species names for readability ----
PC <- PC %>% 
  mutate(SPP = case_when(
    SPP == "Unknown.1" ~ "EUOC",
    SPP == "Unknown.2" ~ "Rush",
    SPP == "Unknown.3" ~ "Weed",
    SPP == "Unknown.4" ~ "VEHA",
    SPP == "Unknown.5" ~ "Weed",
    SPP == "Unknown.6" ~ "EPCI",
    SPP == "Unknown.7" ~ "SOCA",
    SPP == "Unknown.8" ~ "UNK 8",
    TRUE ~ SPP),                  # Leave others as is
    SPP = factor(case_when(
      SPP == "EPCI" ~ "E. ciliatum",
      SPP == "CAMI" ~ "C. minor",
      SPP == "EUMA" ~ "E. maculatum",
      SPP == "EUOC" ~ "E. occidentalis",
      SPP == "GRSQ" ~ "G. squarrosa",
      SPP == "RUMA" ~ "R. maritimus",
      SPP == "SOCA" ~ "S. canadensis",
      SPP == "SYCI" ~ "S. ciliatum",
      SPP == "VEHA" ~ "V. hastata",
      SPP == "PHAU" ~ "P. australis",
      SPP == "DISP" ~ "D. spicata",
      SPP == "BOMA" ~ "B. maritimus",
      SPP == "SCAM" ~ "S. americanus",
      SPP == "SCAC" ~ "S. acutus",
      SPP == "ELPA" ~ "E. palustris",
      SPP == "PUNU" ~ "P. nuttalliana",
      SPP == "MUAS" ~ "M. asperifolia",
      SPP == "JUAR" ~ "J. arcticus",
      SPP == "CAPR" ~ "C. praegracilis",
      SPP == "Cattail" ~ "Typha spp",
      TRUE ~ SPP)), 
    Cover = case_when(
      Cover == "0" ~ 0.5,
      Cover == "1" ~ 5.5,
      Cover == "10" ~ 15,
      Cover == "20" ~ 25,
      Cover == "30" ~ 35,
      Cover == "30 " ~ 35,
      Cover == "40" ~ 45,
      Cover == "50" ~ 55,
      Cover == "60" ~ 65,
      Cover == "70" ~ 75,
      Cover == "80" ~ 85,
      Cover == "90" ~ 94.5,
      Cover == "99" ~ 99.5,
      is.na(Cover) ~ 0,
      TRUE ~ Cover),
    Treatment_Number = as.character(Treatment_Number), # for case_when
    Treatment_Number = case_when(Treatment_Number == "1-C" ~ "1",
                                 Treatment_Number == "34-C" ~ "34",
                                 Treatment_Number == "60-C" ~ "60",
                                 Treatment_Number == "75-C" ~ "75",
                                 Treatment_Number == "90-C" ~ "90",
                                 Treatment_Number == "126-C" ~ "126",
                                 TRUE ~ Treatment_Number),
    Treatment_Number = factor(Treatment_Number,
                              levels = 1:126) # Return to factor
  )
unique(PC$Treatment_Number)

# Check for any typos ----
unique(PC$Cover)
unique(PC$SPP)         

# Left join with Treatment info ----
# Load treatment info
list.files()
Tmt <- read.csv("Greenhouse_Treatment_Locations.csv", header = T)
head(Tmt)
Tmt <- Tmt %>% 
  rename("Treatment_Number" = "ï..Number") %>% 
  mutate(Treatment_Number = factor(Treatment_Number))

## Left join, drop unnecessary cols, clean up naming ----
unique(PC$SPP)
PC <- PC %>% 
  left_join(Tmt, by = "Treatment_Number") %>% 
  select(c(1:2, 4:8)) %>% 
  mutate(Status = factor(case_when(
    SPP %in% c("E. ciliatum", "E. maculatum", "E. occidentalis", "G. squarrosa",
               "R. maritimus", "S. canadensis", "S. ciliatum", "C. minor", 
               "V. hastata", 
               "D. spicata", "B. maritimus", "S. americanus", "S. acutus",
               "E. palustris", "P. nuttalliana", "M. asperifolia",
               "J. arcticus", "C. praegracilis", "Rush", "UNK 8") ~ "Native",
    SPP == "P. australis" ~ "Invasive",
    SPP %in% c("Weed", "Typha spp") ~ "Not Seeded")),
    Salinity = factor(case_when(Salinity == "MED" ~ "Medium",
                                Salinity == "FRESH" ~ "Fresh",
                                Salinity == "HIGH" ~ "High"),
                      levels = c("Fresh", "Medium", "High")),
    Water_Level = factor(case_when(Water_Level == "D" ~ "Moist",
                                   Water_Level == "S" ~ "Saturated"),
                         levels = c("Saturated", "Moist")),
    Seed_Mix =  factor(case_when(Seed_Mix == "FORB" ~ "Forbs",
                                 Seed_Mix == "FORB-W-PHAU" ~ "Forbs with phragmites",
                                 Seed_Mix == "GRAM" ~ "Graminoids",
                                 Seed_Mix == "GRAM-W-PHAU" ~ "Graminoids with phragmites",
                                 Seed_Mix == "PHAU" ~ "Phragmites",
                                 Seed_Mix == "CONTROL" ~ "Control"),
                       levels = c("Control", "Forbs", "Forbs with phragmites",
                                  "Graminoids", "Graminoids with phragmites",
                                  "Phragmites"))) %>% 
  rename("ID" = "Treatment_Number") %>% 
  filter(Status %in% c("Native", "Invasive"), # Remove non-seeded stuff
         Seed_Mix %in% c("Forbs", "Graminoids") & Status == "Native" |
           Seed_Mix %in% c("Phragmites") & Status == "Invasive" |
           Seed_Mix %in% c("Forbs with phragmites", "Graminoids with phragmites",
                           "Control") & Status %in% c("Native", "Invasive")) 

sapply(PC, class)
sapply(PC, unique)

# Save data object ----
getwd()
setwd("../Processed_Data")
save(PC, file = "DF_Manuscript_Percent-Cover.RData")
list.files()


