# In this script we analyze the invasive biomass data from GH 2023 experiment
# We remove the 'Graminoids with phragmites' mix according to feedback from
# S. Durham

# Load required packages ----
library(tidyverse)
library(glmmTMB)
library(DHARMa)
library(emmeans)

# Set contrasts for Type III tests
options(contrasts = c("contr.sum", "contr.poly")) 

# Load Data ----
# Set your working directory to where you saved the processed data frame
setwd()
list.files()
load("DF_Manuscript_Biomass.RData")

tmp <- Bio %>% 
  group_by(Bucket, Seed_Mix, Salinity, Water_Level, Status) %>% 
  summarize(Total_Weight = sum(Weight),
            nObs = n()) %>% 
  ungroup()

Bio <- tmp %>% 
  filter(Status == "Invasive") %>% 
  mutate(Status = factor(Status), # re-level the dataframe
         Seed_Mix = factor(Seed_Mix),
         Bucket = factor(Bucket))

# Checking for 4nobs()# Checking for 4 observations in correct treatments (even if that obs. is 0)
# (This experiment had 4 replicates).
table(Bio$Seed_Mix, Bio$Salinity, Bio$Water_Level, Bio$Status)

# min/max of data
min(Bio$Total_Weight)
max(Bio$Total_Weight)

sapply(Bio, levels)

hist(Bio$Total_Weight) # Likely will want to log transform, many 0's

Bio %>%
  group_by(Seed_Mix) %>%
  summarize(n = n(),
            across(Total_Weight, ~sum(is.na(.) | . == 0)))

# 20 zeros out of 72 observations; this is a high proportion
# Plus ALL are in "Graminoids with phragmites" (20 zeros out of 24 obsns)
# We remove the seed mix 'Graminoids with phragmites' from this model
# after lengthy discussion re: the quality of data from this seed mix,
# and the role in analysis that this
# seed mix provides 

# Remove 'Graminoids with phragmites' mix from analysis ----

Bio <- Bio %>%
  filter(Seed_Mix != "Graminoids with phragmites") %>%
  mutate(Seed_Mix = factor(Seed_Mix))

summary(Bio)

# Model ----
m1 <- glmmTMB(Total_Weight ~ (Seed_Mix + Salinity + Water_Level)^3,
              family = lognormal(),
              data = Bio)
summary(m1)
m1.resid <- simulateResiduals(m1, plot = T)
plotResiduals(m1.resid, form = Bio$Water_Level)
plotResiduals(m1.resid, form = Bio$Salinity)
plotResiduals(m1.resid, form = Bio$Seed_Mix)

m2 <- glmmTMB(Total_Weight ~ (Seed_Mix + Salinity + Water_Level)^3,
              family = lognormal(),
              dispformula = ~Salinity,
              data = Bio)
summary(m2)
m2.resid <- simulateResiduals(m2, plot = T)
plotResiduals(m2.resid, form = Bio$Water_Level)
plotResiduals(m2.resid, form = Bio$Salinity)
plotResiduals(m2.resid, form = Bio$Seed_Mix)


AICcmodavg::AICc(m1); AICcmodavg::AICc(m1, return.K = T)
AICcmodavg::AICc(m2); AICcmodavg::AICc(m2, return.K = T)
# Model not improved

# Anova ----
car::Anova(m1, type = 3)
# Strong support for a 3 way interaction

# Three different interaction plot formats
emmip(m1, Seed_Mix ~ Salinity | Water_Level, CIs = T)
emmip(m1, Seed_Mix ~ Salinity | Water_Level)
emmip(m1, Water_Level ~ Salinity | Seed_Mix)
emmip(m1, Seed_Mix ~ Water_Level | Salinity, CIs = T)
# Does this 3-way interaction make biological sense?
# It has too much support to be ignored.

# Compare observed data on the log scale to the corresponding model emmip
ggplot(Bio,
       aes(x = Water_Level, y = log(Total_Weight), 
           fill = Seed_Mix)) +
  geom_boxplot(outlier.shape = NA) +
  geom_point(position = position_jitterdodge(jitter.width = 0.1)) + 
  facet_wrap(~ Salinity)

emmip(m1, Seed_Mix ~ Water_Level | Salinity, CIs = T)

# Observed data on data scale; compare this figure to the corresponding emmip
ggplot(Bio,
       aes(x = Water_Level, y = Total_Weight, 
           fill = Seed_Mix)) +
  geom_boxplot(outlier.shape = NA) +
  geom_point(position = position_jitterdodge(jitter.width = 0.1)) + 
  facet_wrap(~ Salinity)

emmip(m1, Seed_Mix ~ Water_Level | Salinity, CIs = T, type = "response")


# Custom contrasts ----
## Water contrasts ----
(emm.order <- emmeans(m1, ~ Seed_Mix + Salinity + Water_Level))

ForbPh.Fresh <- c(1, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0)
Ph.Fresh <- c(0, 1, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0)
ForbPh.Med <- c(0, 0, 1, 0, 0, 0, 0, 0, -1, 0, 0, 0)
Ph.Med <- c(0, 0, 0, 1, 0, 0, 0, 0, 0, -1, 0, 0)
ForbPh.Hi <- c(0, 0, 0, 0, 1, 0, 0, 0, 0, 0, -1, 0)
Ph.Hi <- c(0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, -1)

(water <- contrast(emm.order, 
                   method = list("Phragmites Fresh Sat - Moi" = Ph.Fresh,
                                 "Forbs with phragmites Fresh Sat - Moi" = 
                                   ForbPh.Fresh,
                                 "Phragmites Medium Sat - Moi" = Ph.Med,
                                 "Forbs with phragmites Medium Sat - Moi" = 
                                   ForbPh.Med,
                                 "Phragmites High Sat - Moi" = Ph.Hi,
                                 "Forbs with Phragmites High Sat - Moi" = 
                                   ForbPh.Hi),
                   adjust = "sidak"))
# No evidence for a difference in forbs with phragmites biomass resulting
# from water level
# Phragmites (by itself) has a difference at freshwater level, maybe med
# not high


## Contrasts between mixes for fresh, med accounting for water level ----
# high is averaged between water level (no water level diff. found)

### Fresh ----
c.s.fresh <- c(1, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0)
c.m.fresh <- c(0, 0, 0, 0, 0, 0, 1, -1, 0, 0, 0, 0)

(f <- contrast(emm.order, method = list(
  "Forbs with phragmites - Phragmites at Saturated" = c.s.fresh,
  "Forbs with phragmites - Phragmites at Moist" = c.m.fresh),
  adjust = "sidak"))
# Phragmites grew better by itself under saturated conditions than in the
# Forbs with phragmites mix


### Medium ----
c.s.med <- c(0, 0, 1, -1, 0, 0, 0, 0, 0, 0, 0, 0)
c.m.med <- c(0, 0, 0, 0, 0, 0, 0, 0, 1, -1, 0, 0)

(m <- contrast(emm.order, method = list(
  "Forbs with phragmites - Phragmites at Saturated" = c.s.med,
  "Forbs with phragmites - Phragmites at Moist" = c.m.med),
  adjust = "sidak"))
# Forbs with phragmites grew better under saturated than Phragmites alone

### High ----
c.avg.high <- c(0, 0, 0, 0, 0.5, -0.5, 0, 0, 0, 0, 0.5, -0.5)

(h <- contrast(emm.order, method = list(
  "Forbs with phragmites - Phragmites Averaged" = c.avg.high))) 
# no adjustment necessary, only 1 contrast

f
m
h

# In Saturated, PHAU weight is _higher_ in 
#   Phragmites alone than in combination with Forbs in Fresh salinity.
#   But PHAU weight is _lower_ in Phragmites alone than in combination 
#   with Forbs in Medium salinity. In High salinity, there is no support
#   for a Seed_Mix difference.


## Salinity comparisons ----
# Phragmites accounts for water level
# Forbs with phragmites is averaged across water levels
(emm.order <- emmeans(m1, ~ Seed_Mix + Salinity + Water_Level))

ph.sat.FH <- c(0, 1, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0)
ph.sat.FM <- c(0, 1, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0)
ph.sat.MH <- c(0, 0, 0, 1, 0, -1, 0, 0, 0, 0, 0, 0)
ph.moi.FH <- c(0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, -1)
ph.moi.FM <- c(0, 0, 0, 0, 0, 0, 0, 1, 0, -1, 0, 0)
ph.moi.MH <- c(0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, -1)

(phrag.both <- contrast(emm.order, 
                        method = list("Fresh - High, Ph MOI" = ph.moi.FH,
                                      "Fresh - Medium, Ph MOI" = ph.moi.FM,
                                      "Medium - High, Ph MOI" = ph.moi.MH,
                                      "Fresh - High, Ph SAT" = ph.sat.FH,
                                      "Fresh - Medium, Ph SAT" = ph.sat.FM,
                                      "Medium - High, Ph SAT" = ph.sat.MH),
                        adjust = "sidak"))

forbPh.avg.FH <- c(0.5, 0, 0, 0, -0.5, 0, 0.5, 0, 0, 0, -0.5, 0)
forbPh.avg.FM <- c(0.5, 0, -0.5, 0, 0, 0, 0.5, 0, -0.5, 0, 0, 0)
forb.Ph.avg.MH <- c(0, 0, 0.5, 0, -0.5, 0, 0, 0, 0.5, 0, -0.5, 0)
(forbPH.avg <- contrast(emm.order, 
                       method = list("Fresh - High, forbPh" = forbPh.avg.FH, 
                                     "Fresh - Medium, forbPh" = forbPh.avg.FM,
                                     "Medium - High, forbPh" = forb.Ph.avg.MH),
                       adjust = "sidak"))


# Save model means for graph
(emm2 <- emmeans(m1, 
                 ~ Salinity | Seed_Mix * Water_Level, 
                 type = "response"))
  
  
# Save model objects ----
# To be used for graphs and figures
setwd("../Processed_Data")
save(Bio, m1, emm2, water, f, m, h, phrag.both, forbPH.avg,
     file = "Manuscript_Model-Objects_IB.RData")


# Save ANODEV table ----
## Source rounding functions, created in a separate script ----
getwd()
setwd("../")
list.files()
source("Function_round.R")

# Create table of ANODEV
IB_an <- as.data.frame(car::Anova(m1, type = 3))
IB_an
summary(m1)
colnames(IB_an)

# Change header names
IB_an <- IB_an %>% 
  rownames_to_column(var = ".") %>% 
  rename(Pr = "Pr(>Chisq)")

# Round table values  
IB_an <- IB_an %>% 
  mutate(Pr = P.round(Pr),
         Chisq = FTChi.round(Chisq))

# Make table
IB_ANODEV <- flextable(data = IB_an) %>% 
  hline(i = NULL, 
        part = "header", 
        border = fp_border(color = "black", 
                           width = 2.0, 
                           style = "solid")) %>% 
  hline_bottom(j = NULL, part = "body",
               border = fp_border(color = "black", 
                                  width = 2.0, 
                                  style = "solid"))
IB_ANODEV
setwd("./Output")  
save_as_docx(IB_ANODEV, path = "Manuscript_Table_IB_ANODEV.docx", 
             pr_section = 
               prop_section(page_size = page_size(orient = "portrait"), 
                            type = "continuous"))  

