# In this script we analyze the native biomass data from GH 2023 experiment
# We remove the 'Graminoids with phragmites' mix according to feedback from
# S. Durham

# Load required packages ----
library(tidyverse)
library(glmmTMB)
library(DHARMa)
library(emmeans)

# Set contrasts for Type III tests
options(contrasts = c("contr.sum", "contr.poly")) 

# Load Data ----
# Set your working directory to where you saved the processed data frame
setwd()
list.files()
load("DF_Manuscript_Biomass.RData")

tmp <- Bio %>% 
  group_by(Bucket, Seed_Mix, Salinity, Water_Level, Status) %>% 
  summarize(Total_Weight = sum(Weight),
            nObs = n()) %>% 
  ungroup()

Bio <- tmp %>% 
  filter(Status == "Native") %>% 
  mutate(Status = factor(Status), # re-level the dataframe
         Seed_Mix = factor(Seed_Mix),
         Bucket = factor(Bucket))


# Checking for 4nobs()# Checking for 4 observations in correct treatments 
# (even if that obs. is 0)
# (This experiment had 4 replicates).
table(Bio$Seed_Mix, Bio$Salinity, Bio$Water_Level, Bio$Status)

# min/max of data
min(Bio$Total_Weight)
max(Bio$Total_Weight)

sapply(Bio, levels)

hist(Bio$Total_Weight) # Likely will want to log transform, many 0's

Bio %>%
  group_by(Seed_Mix) %>%
  summarize(n = n(),
            across(Total_Weight, ~sum(is.na(.) | . == 0)))

# 8 zeros out of 72 observations
# Plus ALL are in "Graminoids with phragmites" (8 zeros out of 24 obsns)

# We remove the seed mix 'Graminoids with phragmites' from this model
# after lengthy discussion re: the quality of data from this seed mix,
# and the role in analysis that this
# seed mix provides 

# Remove 'Graminoids with phragmites' mix from analysis ----

Bio <- Bio %>%
  filter(Seed_Mix != "Graminoids with phragmites") %>%
  mutate(Seed_Mix = factor(Seed_Mix))

summary(Bio)
hist(Bio$Total_Weight) # log of data likely still needed

# Model ----
m1 <- glmmTMB(Total_Weight ~ (Seed_Mix + Salinity + Water_Level)^3,
              family = lognormal(),
              data = Bio)

summary(m1)
m1.resid <- simulateResiduals(m1, plot = T)
plotResiduals(m1.resid, form = Bio$Water_Level)
plotResiduals(m1.resid, form = Bio$Salinity)
plotResiduals(m1.resid, form = Bio$Seed_Mix)

# Anova ----
car::Anova(m1, type = 3)
# car::Anova(m1, type = 2)
# No support for a 3 way interaction
# Strong support for Seed_Mix:Salinity interaction (as expected)
# Moderate support for Seed_Mix:Water_Level interaction

# Different interaction plot formats
emmip(m1, Seed_Mix ~ Salinity)
emmip(m1, Seed_Mix ~ Salinity, CIs = T)

emmip(m1, Seed_Mix ~ Water_Level)
emmip(m1, Seed_Mix ~ Water_Level, CIs = T)


# Compare observed data on the log scale to the corresponding model emmip
ggplot(Bio,
       aes(x = Salinity, y = log(Total_Weight), 
           fill = Seed_Mix)) +
  geom_boxplot(outlier.shape = NA) +
  geom_point(position = position_jitterdodge(jitter.width = 0.1)) 

emmip(m1, Seed_Mix ~ Salinity, CIs = T)

# Observed data on data scale; compare this figure to the corresponding emmip
ggplot(Bio,
       aes(x = Salinity, y = Total_Weight, 
           fill = Seed_Mix)) +
  geom_boxplot(outlier.shape = NA) +
  geom_point(position = position_jitterdodge(jitter.width = 0.1))

emmip(m1, Seed_Mix ~ Salinity, CIs = T, type = "response")


# Is there interaction within each Salinity level?

# Within salinity, comparisons between seed mixes
emm1 <- emmeans(m1, 
                pairwise ~ Seed_Mix | Salinity,
                adjust = "tukey")
emm1
emm1$contrasts 

# native cover unaffected by presence of phrag 
# Forbs greater than grams in fresh, med
# all greatly reduced at high salinity


# Across salinity, comparisons within a single seed mix
emm2 <- emmeans(m1, 
                pairwise ~ Salinity | Seed_Mix,
                adjust = "tukey")
emm2
emm2$contrasts
# All seed mixes reduced with increasing salinity (at high salinity)

# Moderate support for a seed_mix:water_level interaction
emm3 <- emmeans(m1, 
                pairwise ~ Seed_Mix | Water_Level,
                adjust = "tukey")
emm3

emm4 <- emmeans(m1, 
                pairwise ~ Water_Level | Seed_Mix) 
# Only 1 comparison, no adjustmet needed
emm4

# moderate support for
# Forbs with phragmites had lower native biomass at saturated than forbs by itself
# Maybe because phragmites grows well in saturated conditions, and thus limited
# forb (native) growth when sown together. check with invasive graphs again

# moderate support for a drop in biomass in the forb mix from saturated to moist
# but not in any other seed mix


# Save emmeans on response scale for graph ----
wa <- emmeans(m1, 
              pairwise ~ Seed_Mix | Water_Level,
              type = "response",
              adjust = "tukey")
  
sal <- emm2 <- emmeans(m1, 
                       pairwise ~ Salinity | Seed_Mix,
                       type = "response",
                       adjust = "tukey")


# Save model objects ----
# To be used for graphs and figures
setwd("../Processed_Data")
save(Bio, m1, emm1, emm2, emm3, emm4, wa, sal, 
     file = "Manuscript_Model-Objects_NB.RData")


# Save ANODEV table ----
## Source rounding functions, created in a separate script ----
getwd()
setwd("../")
list.files()
source("Function_round.R")

# Create table of ANODEV
NB_an <- as.data.frame(car::Anova(m1, type = 3))
NB_an
summary(m1)
colnames(NB_an)

# Change header names
NB_an <- NB_an %>% 
  rownames_to_column(var = ".") %>% 
  rename(Pr = "Pr(>Chisq)")

# Round table values  
NB_an <- NB_an %>% 
  mutate(Pr = P.round(Pr),
         Chisq = FTChi.round(Chisq))

# Make table
NB_ANODEV <- flextable(data = NB_an) %>% 
  hline(i = NULL, 
        part = "header", 
        border = fp_border(color = "black", 
                           width = 2.0, 
                           style = "solid")) %>% 
  hline_bottom(j = NULL, part = "body",
               border = fp_border(color = "black", 
                                  width = 2.0, 
                                  style = "solid"))
NB_ANODEV
setwd("./Output")  
save_as_docx(NB_ANODEV, path = "Manuscript_Table_NB_ANODEV.docx", 
             pr_section = 
               prop_section(page_size = page_size(orient = "portrait"), 
                            type = "continuous"))  
