# In this script we analyze the invasive percent cover data from GH 2023 experiment
# We remove the 'graminoids w/ P. australis' mix according to feedback from
# S. Durham

# Load required packages ----
library(tidyverse)
library(glmmTMB)
library(DHARMa)
library(emmeans)
library(flextable)
library(officer)

# Set contrasts for Type III tests 
options(contrasts = c("contr.sum", "contr.poly"))

# Load Data ----
# Set your working directory to where you saved the processed data frame
setwd()
list.files()
load("DF_Manuscript_Percent-Cover.RData")

PC <- PC %>% 
  rename("Bucket" = "ID")

tmp <- PC %>% 
  filter(Date == max(Date)) %>% 
  group_by(Bucket, Seed_Mix, Salinity, Water_Level, Status) %>% 
  summarize(Total_Cover = sum(Cover),
            nObs = n()) %>% 
  ungroup()

PC <- tmp %>% 
  filter(Status == "Invasive" & Seed_Mix != "Control") %>% 
  mutate(Status = factor(Status), # re-level the dataframe
         Seed_Mix = factor(Seed_Mix),
         Bucket = factor(Bucket))

# Checking for 4nobs()# Checking for 4 observations in correct treatments 
# (even if that obs. is 0)
# (This experiment had 4 replicates).
table(PC$Seed_Mix, PC$Salinity, PC$Water_Level, PC$Status)

# min/max of data
min(PC$Total_Cover)
max(PC$Total_Cover)

sapply(PC, levels)

hist(PC$Total_Cover) # Likely will want to log transform, many 0's

PC %>%
  group_by(Seed_Mix) %>%
  summarize(n = n(),
            across(Total_Cover, ~sum(is.na(.) | . == 0)))

# 20 zeroes, and all are from the Graminoids with phragmites mix 
# (out of 24 obsns in that mix)

# We remove the seed mix 'Graminoids with phragmites' from this model
# after lengthy discussion re: the quality of data from this seed mix,
# and the role in analysis that this
# seed mix provides 

# Remove 'Graminoids with phragmites' mix from analysis ----

PC <- PC %>%
  filter(Seed_Mix != "Graminoids with phragmites") %>%
  mutate(Seed_Mix = factor(Seed_Mix))

summary(PC)
hist(PC$Total_Cover) # log of data likely still needed

# Model ----
m1 <- glmmTMB(Total_Cover ~ (Seed_Mix + Salinity + Water_Level)^3,
              family = lognormal(),
              data = PC)

summary(m1)
m1.resid <- simulateResiduals(m1, plot = T)
plotResiduals(m1.resid, form = PC$Water_Level)
plotResiduals(m1.resid, form = PC$Salinity)
plotResiduals(m1.resid, form = PC$Seed_Mix)

# Anova ----
car::Anova(m1, type = 3)
# strong evidence for a 3-way interaction

# Three different interaction plot formats
emmip(m1, Seed_Mix ~ Salinity | Water_Level)
emmip(m1, Water_Level ~ Salinity | Seed_Mix)
emmip(m1, Seed_Mix ~ Water_Level | Salinity, CIs = T)
emmip(m1, Seed_Mix ~ Salinity | Water_Level, CIs = T)
# Does this 3-way interaction make biological sense?
# It has too much support to be ignored.


# Compare observed data on the log scale to the corresponding model emmip
ggplot(PC,
       aes(x = Water_Level, y = log(Total_Cover), 
           fill = Seed_Mix)) +
  geom_boxplot(outlier.shape = NA) +
  geom_point(position = position_jitterdodge(jitter.width = 0.1)) + 
  facet_wrap(~ Salinity)

emmip(m1, Seed_Mix ~ Water_Level | Salinity, CIs = T)

# Observed data on data scale; compare this figure to the corresponding emmip
ggplot(PC,
       aes(x = Water_Level, y = Total_Cover, 
           fill = Seed_Mix)) +
  geom_boxplot(outlier.shape = NA) +
  geom_point(position = position_jitterdodge(jitter.width = 0.1)) + 
  facet_wrap(~ Salinity)

emmip(m1, Seed_Mix ~ Water_Level | Salinity, CIs = T, type = "response")


# Contrasts -----

## Water contrasts ----
(emm.order <- emmeans(m1, ~ Seed_Mix + Salinity + Water_Level))

ForbPh.Fresh <- c(1, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0)
Ph.Fresh <- c(0, 1, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0)
ForbPh.Med <- c(0, 0, 1, 0, 0, 0, 0, 0, -1, 0, 0, 0)
Ph.Med <- c(0, 0, 0, 1, 0, 0, 0, 0, 0, -1, 0, 0)
ForbPh.Hi <- c(0, 0, 0, 0, 1, 0, 0, 0, 0, 0, -1, 0)
Ph.Hi <- c(0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, -1)

(water <- contrast(emm.order, 
                   method = list("Phragmites Fresh Sat - Moi" = Ph.Fresh,
                                 "Forbs with phragmites Fresh Sat - Moi" = 
                                   ForbPh.Fresh,
                                 "Phragmites Medium Sat - Moi" = Ph.Med,
                                 "Forbs with phragmites Medium Sat - Moi" = 
                                   ForbPh.Med,
                                 "Phragmites High Sat - Moi" = Ph.Hi,
                                 "Forbs with Phragmites High Sat - Moi" = 
                                   ForbPh.Hi),
                   adjust = "sidak"))

# Diff b/n water levels for Phragmites mix Fresh and Med salinity,
# Diff b/n water levels for Forbs with Phragmites at High salinity.
# So we need to do across salinity contrasts accounting for water level


## Contrasts between mixes for fresh, med accounting for water level ----
# high is averaged between water level (no interaction found)

### Fresh ----
c.s.fresh <- c(1, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0)
c.m.fresh <- c(0, 0, 0, 0, 0, 0, 1, -1, 0, 0, 0, 0)

(f <- contrast(emm.order, method = list(
  "Forbs with phragmites - Phragmites at Saturated" = c.s.fresh,
  "Forbs with phragmites - Phragmites at Moist" = c.m.fresh),
  adjust = "sidak"))
# Phragmites grew better by itself under saturated conditions than in the
# Forbs with phragmites mix


### Medium ----
c.s.med <- c(0, 0, 1, -1, 0, 0, 0, 0, 0, 0, 0, 0)
c.m.med <- c(0, 0, 0, 0, 0, 0, 0, 0, 1, -1, 0, 0)

(m <- contrast(emm.order, method = list(
  "Forbs with phragmites - Phragmites at Saturated" = c.s.med,
  "Forbs with phragmites - Phragmites at Moist" = c.m.med),
  adjust = "sidak"))

### High ----
c.s.high <- c(0, 0, 0, 0, 1, -1, 0, 0, 0, 0, 0, 0)
c.m.high <- c(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, -1)

(h <- contrast(emm.order, method = list(
  "Forbs with phragmites - Phragmites at Saturated" = c.s.high,
  "Forbs with phragmites - Phragmites at Moist" = c.m.high),
  adjust = "sidak"))

f
m
h

# In Moist, there is no support for a Seed_Mix effect on PHAU weight for any 
# Salinity level. 

# In Saturated, PHAU weight is _higher_ in 
#   Phragmites alone than in combination with Forbs in Fresh salinity.
#   But, moderate evidence -- that PHAU weight is _lower_ in Phragmites alone 
#   than in combination with Forbs in Medium salinity. 
#   In High salinity, no difference


# Across salinity, comparisons within a single seed mix
(emm2 <- emmeans(m1, 
                pairwise ~ Salinity | Seed_Mix * Water_Level,
                adjust = "tukey"))

gra <- emmeans(m1, 
               pairwise ~ Salinity | Seed_Mix * Water_Level,
               type = "response",
               adjust = "tukey")
gra <- gra$emmeans

# Save model objects ----
# To be used for graphs and figures
setwd("../Processed_Data")
save(PC, m1, water, f, m, h, emm2, gra,
     file = "Manuscript_Model-Objects_IC.RData")


# Save ANODEV table ----
## Source rounding functions, created in a separate script ----
getwd()
setwd("../")
list.files()
source("Function_round.R")

# Create table of ANODEV
IC_an <- as.data.frame(car::Anova(m1, type = 3))
IC_an
summary(m1)
colnames(IC_an)

# Change header names
IC_an <- IC_an %>% 
  rownames_to_column(var = ".") %>% 
  rename(Pr = "Pr(>Chisq)")

# Round table values  
IC_an <- IC_an %>% 
  mutate(Pr = P.round(Pr),
         Chisq = FTChi.round(Chisq))

# Make table
IC_ANODEV <- flextable(data = IC_an) %>% 
  hline(i = NULL, 
        part = "header", 
        border = fp_border(color = "black", 
                           width = 2.0, 
                           style = "solid")) %>% 
  hline_bottom(j = NULL, part = "body",
               border = fp_border(color = "black", 
                                  width = 2.0, 
                                  style = "solid"))
IC_ANODEV
setwd("./Output")  
save_as_docx(IC_ANODEV, path = "Manuscript_Table_IC_ANODEV.docx", 
             pr_section = 
               prop_section(page_size = page_size(orient = "portrait"), 
                            type = "continuous"))  

