# In this script we analyze the native percent cover data from GH 2023 experiment
# We remove the 'graminoids w/ P. australis' mix according to feedback from
# S. Durham

# Load required packages ----
library(tidyverse)
library(glmmTMB)
library(DHARMa)
library(emmeans)
library(flextable)
library(officer)

# Set contrasts for Type III tests 
options(contrasts = c("contr.sum", "contr.poly"))

# Load Data ----
# Set your working directory to where you saved the processed data frame
setwd()
list.files()
load("DF_Manuscript_Percent-Cover.RData")

PC <- PC %>% 
  rename("Bucket" = "ID")

tmp <- PC %>% 
  filter(Date == max(Date)) %>% 
  group_by(Bucket, Seed_Mix, Salinity, Water_Level, Status) %>% 
  summarize(Total_Cover = sum(Cover),
            nObs = n()) %>% 
  ungroup()

PC <- tmp %>% 
  filter(Status == "Native" & Seed_Mix != "Control") %>% 
  mutate(Status = factor(Status), # re-level the dataframe
         Seed_Mix = factor(Seed_Mix),
         Bucket = factor(Bucket))

# Checking for 4nobs()# Checking for 4 observations in correct treatments 
# (even if that obs. is 0)
# (This experiment had 4 replicates).
table(PC$Seed_Mix, PC$Salinity, PC$Water_Level, PC$Status)

# min/max of data
min(PC$Total_Cover)
max(PC$Total_Cover)

sapply(PC, levels)

hist(PC$Total_Cover) # Likely will want to log transform, many 0's

PC %>%
  group_by(Seed_Mix) %>%
  summarize(n = n(),
            across(Total_Cover, ~sum(is.na(.) | . == 0)))

# 8 zeroes, and all are from the Graminoids with phragmites mix 
# (out of 24 obsns in that mix)

# We remove the seed mix 'Graminoids with phragmites' from this model
# after lengthy discussion re: the quality of data from this seed mix,
# and the role in analysis that this
# seed mix provides 

# Remove 'Graminoids with phragmites' mix from analysis ----

PC <- PC %>%
  filter(Seed_Mix != "Graminoids with phragmites") %>%
  mutate(Seed_Mix = factor(Seed_Mix))

summary(PC)
hist(PC$Total_Cover) # log of data likely still needed

# Model ----
m1 <- glmmTMB(Total_Cover ~ (Seed_Mix + Salinity + Water_Level)^3,
              family = lognormal(),
              data = PC)

summary(m1)
m1.resid <- simulateResiduals(m1, plot = T)
plotResiduals(m1.resid, form = PC$Water_Level)
plotResiduals(m1.resid, form = PC$Salinity)
plotResiduals(m1.resid, form = PC$Seed_Mix)

# Anova ----
car::Anova(m1, type = 3)
# strong evidence for a 3 way interaction

# 3-way plot ----
emmip(m1, Seed_Mix ~ Salinity | Water_Level, CIs = T)
emmip(m1, Seed_Mix ~ Salinity | Water_Level, CIs = T, type = "response")
emmip(m1, Water_Level ~ Salinity | Seed_Mix, CIs = T)
emmip(m1, Seed_Mix ~ Water_Level | Salinity, CIs = T)
# Does this 3-way interaction make biological sense?

(emm.order <- emmeans(m1, ~ Seed_Mix + Salinity + Water_Level))

## Across Water contrasts ----
### Forbs ----
f.fresh <- c(1, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0)
f.med <- c(0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0)
f.high <- c(0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0)

(f <- contrast(emm.order, method = list(
  "Forbs Saturated - Moist at Fresh" = f.fresh,
  "Forbs Saturated - Moist at Medium" = f.med,
  "Forbs Saturated - Moist at High" = f.high),
  adjust = "sidak"))

### Forbs with phragmites
fp.fresh <- c(0, 1, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0)
fp.med <- c(0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0)
fp.high <- c(0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0)

(fp <- contrast(emm.order, method = list(
  "Forbs with phragmites Saturated - Moist at Fresh" = fp.fresh,
  "Forbs with phragmites Saturated - Moist at Medium" = fp.med,
  "Forbs with phragmites Saturated - Moist at High" = fp.high),
  adjust = "sidak"))

### Graminoids
g.fresh <- c(0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0)
g.med <- c(0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, -1, 0, 0, 0)
g.high <- c(0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, -1)

(g <- contrast(emm.order, method = list(
  "Graminoids Saturated - Moist at Fresh" = g.fresh,
  "Graminoids Saturated - Moist at Medium" = g.med,
  "Graminoids Saturated - Moist at High" = g.high),
  adjust = "sidak"))

f <- as.data.frame(f)
fp <- as.data.frame(fp)
g <- as.data.frame(g)
(water <- rbind(f, fp, g))

# Forbs are not different across water levels
# Forbs with phragmites grew better in saturated fresh
# Graminoids grew worse in saturated fresh
# Suspect this is partly the result of low replication, noise in data


# Within salinity contrasts -----
(emm.order <- emmeans(m1, ~ Seed_Mix + Salinity + Water_Level))

### Fresh ----
# Forbs with phragmites and Graminoids both have differences in water level at 
# fresh salinity, so contrasts will account for water levels at fresh sal. only
Fre.ForbSat.GramSat <- c(1, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0)
Fre.ForbMoi.GramMoi <- c(0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, -1, 0, 0, 0, 0, 0, 0)
Fre.ForbSat.ForbPhSat <- c(1, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0)
Fre.ForbMoi.ForbPhMoi <- c(0, 0, 0, 0, 0, 0, 0, 0, 0, 1, -1, 0, 0, 0, 0, 0, 0, 0)
Fre.ForbPhSat.GramSat <- c(0, 1, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0)
Fre.ForbPhMoi.GramMoi <- c(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, -1, 0, 0, 0, 0, 0, 0)

ConWithinFresh <- contrast(emm.order, method = list(
  "Forbs - Graminoids Saturated" = Fre.ForbSat.GramSat,
  "Forbs - Graminoids Moist" = Fre.ForbMoi.GramMoi,
  "Forbs - Forbs with phragmites Saturated" = Fre.ForbSat.ForbPhSat,
  "Forbs - Forbs with phragmites Moist" = Fre.ForbMoi.ForbPhMoi,
  "Forbs with phragmites - Graminoids Saturated" = Fre.ForbPhSat.GramSat,
  "Forbs with phragmites - Graminoids Moist" = Fre.ForbPhMoi.GramMoi),
  adjust = "sidak") 

ConWithinFresh <- as.data.frame(ConWithinFresh) %>% 
  mutate(Salinity = "Fresh")


### Medium ----
# averaged across water levels
Med.Forb.Gram <- c(0, 0, 0, 0.5, 0, -0.5, 0, 0, 0, 0, 0, 0, 0.5, 0, -0.5, 0, 0, 0)
Med.Forb.ForbPh <- c(0, 0, 0, 0.5, -0.5, 0, 0, 0, 0, 0, 0, 0, 0.5, -0.5, 0, 0, 0, 0)
Med.ForbPh.Gram <- c(0, 0, 0, 0, 0.5, -0.5, 0, 0, 0, 0, 0, 0, 0, 0.5, -0.5, 0, 0, 0)

ConWithinMed <- contrast(emm.order, method = list(
  "Forbs - Graminoids" = Med.Forb.Gram,
  "Forbs - Forbs with phragmites" = Med.Forb.ForbPh,
  "Forbs with phragmites - Graminoids" = Med.ForbPh.Gram),
  adjust = "sidak")

ConWithinMed <- as.data.frame(ConWithinMed) %>% 
  mutate(Salinity = "Medium")

### High ----
Hi.Forb.Gram <- c(0, 0, 0, 0, 0, 0, 0.5, 0, -0.5, 0, 0, 0, 0, 0, 0, 0.5, 0, -0.5)
Hi.Forb.ForbPh <- c(0, 0, 0, 0, 0, 0, 0.5, -0.5, 0, 0, 0, 0, 0, 0, 0, 0.5, -0.5, 0)
Hi.ForbPh.Gram <- c(0, 0, 0, 0, 0, 0, 0, 0.5, -0.5, 0, 0, 0, 0, 0, 0, 0, 0.5, -0.5)

ConWithinHi <- contrast(emm.order, method = list(
  "Forbs - Graminoids" = Hi.Forb.Gram,
  "Forbs - Forbs with phragmites" = Hi.Forb.ForbPh,
  "Forbs with phragmites - Graminoids" = Hi.ForbPh.Gram),
  adjust = "sidak")

ConWithinHi <- as.data.frame(ConWithinHi) %>% 
  mutate(Salinity = "High")

WithinSal <- rbind(ConWithinFresh, ConWithinMed, ConWithinHi)
WithinSal


# Across salinity contrasts -----
(emm.order <- emmeans(m1, ~ Seed_Mix + Salinity + Water_Level))

# Forbs with Phragmites and Graminoids both have differences in water level at
# fresh salinity, so contrasts will account for water levels within these mixes,
# but not Forbs 

## Forbs ----
Forb.FM <- c(0.5, 0, 0, -0.5, 0, 0, 0, 0, 0, 0.5, 0, 0, -0.5, 0, 0, 0, 0, 0)
Forb.FH <- c(0.5, 0, 0, 0, 0, 0, -0.5, 0, 0, 0.5, 0, 0, 0, 0, 0, -0.5, 0, 0)
Forb.MH <- c(0, 0, 0, 0.5, 0, 0, -0.5, 0, 0, 0, 0, 0, 0.5, 0, 0, -0.5, 0, 0)

ConForb <- contrast(emm.order, method = list(
  "Fresh - Medium" = Forb.FM,
  "Fresh - High" = Forb.FH,
  "Medium - High" = Forb.MH),
  adjust = "sidak")

ConForb <- as.data.frame(ConForb) %>% 
  mutate(Seed_Mix = "Forbs")


## Forbs with phragmites ----
ForbPh.FMSa <- c(0, 1, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0)
ForbPh.FHSa <- c(0, 1, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0)
ForbPh.MHSa <- c(0, 0, 0, 0, 1, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0)
ForbPh.FMMoi <- c(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, -1, 0, 0, 0, 0)
ForbPh.FHMoi <- c(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, -1, 0)
ForbPh.MHMoi <- c(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, -1, 0)

ConForbPh <- contrast(emm.order, method = list(
  "Fresh - Medium at Saturated" = ForbPh.FMSa,
  "Fresh - High at Saturated" = ForbPh.FHSa,
  "Medium - High at Saturated" = ForbPh.MHSa,
  "Fresh - Medium at Moist" = ForbPh.FMMoi,
  "Fresh - High at Moist" = ForbPh.FHMoi,
  "Medium - High at Moist" = ForbPh.MHMoi),
  adjust = "sidak")

ConForbPh <- as.data.frame(ConForbPh) %>% 
  mutate(Seed_Mix = "Forbs with phragmites")

## Graminoids ----
Gram.FMSa <- c(0, 0, 1, 0, -0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0)
Gram.FHSa <- c(0, 0, 1, 0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0)
Gram.MHSa <- c(0, 0, 0, 0, 0, 1, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0)
Gram.FMMoi <- c(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, -1, 0, 0, 0)
Gram.FHMoi <- c(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, -1)
Gram.MHMoi <- c(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, -1)

ConGram <- contrast(emm.order, method = list(
  "Fresh - Medium at Saturated" = Gram.FMSa,
  "Fresh - High at Saturated" = Gram.FHSa,
  "Medium - High at Saturated" = Gram.MHSa,
  "Fresh - Medium at Moist" = Gram.FMMoi,
  "Fresh - High at Moist" = Gram.FHMoi,
  "Medium - High at Moist" = Gram.MHMoi),
  adjust = "sidak")

ConGram <- as.data.frame(ConGram) %>% 
  mutate(Seed_Mix = "Graminoids")

(AcrossSal <- rbind(ConForb, ConForbPh, ConGram))

# Save model estimates (3-way) ----
# for a table
emm1 <- emmeans(m1, 
                ~ Seed_Mix | Salinity * Water_Level,
                type = "response")
emm1

# Save model objects ----
# To be used for graphs and figures
setwd("../Processed_Data")
save(PC, m1, water, AcrossSal, WithinSal, emm1, 
     file = "Manuscript_Model-Objects_NC.RData")


# Save ANODEV table ----
## Source rounding functions, created in a separate script ----
getwd()
setwd("../")
list.files()
source("Function_round.R")

# Create table of ANODEV
NC_an <- as.data.frame(car::Anova(m1, type = 3))
NC_an
summary(m1)
colnames(NC_an)

# Change header names
NC_an <- NC_an %>% 
  rownames_to_column(var = ".") %>% 
  rename(Pr = "Pr(>Chisq)")

# Round table values  
NC_an <- NC_an %>% 
  mutate(Pr = P.round(Pr),
         Chisq = FTChi.round(Chisq))

# Make table
NC_ANODEV <- flextable(data = NC_an) %>% 
  hline(i = NULL, 
        part = "header", 
        border = fp_border(color = "black", 
                           width = 2.0, 
                           style = "solid")) %>% 
  hline_bottom(j = NULL, part = "body",
               border = fp_border(color = "black", 
                                  width = 2.0, 
                                  style = "solid"))
NC_ANODEV
setwd("./Output")  
save_as_docx(NC_ANODEV, path = "Manuscript_Table_NC_ANODEV.docx", 
             pr_section = 
               prop_section(page_size = page_size(orient = "portrait"), 
                            type = "continuous"))  

