# In this script we analyze the end of experiment soil salinity for the
# 2023 Greenhouse Experiment

# Load packages ----
library(tidyverse)
library(glmmTMB)
library(DHARMa)
library(emmeans)
library(officer)
library(flextable)

# Load Data ----
# Set your working directory to where you saved the processed data frame
setwd()

source("Function_round.R")
load("DF_Salinity-Soil.RData")

# Set contrasts, for Type 3 Anova
options(contrasts = c("contr.sum", "contr.poly")) 

# Data Wrangle ----
head(SS)
SS <- SS %>% 
  mutate(Water_Level = factor(Water_Level,
                              levels = c("Saturated", "Drought"))) # Put Sat before Dr

# Salinity Levels 
# Fresh, Med = 8 dS/m, High = 16 dS/m

# Graph Raw Data  ----
SS %>% 
  ggplot(aes(x = Salinity,
             y = ECe,
             fill = Position)) +
  geom_boxplot() +
  theme_bw() +
  scale_fill_brewer(palette = "BuGn") +
  labs(title = "End of Experiment Soil Salinity",
       x = "Salinity Treatment",
       y = "ECe dS/m") +
  theme(axis.title.x = element_text(size = 24),
        axis.text.x = element_text(size = 22),
        axis.title.y = element_text(size = 24),
        axis.text.y = element_text(size = 22),
        title = element_text(size = 24),
        legend.title = element_text(size = 24),
        legend.text = element_text(size = 24),
        strip.text = element_text(size = 24))+
  facet_wrap(SS$Water_Level)


# Overall Salinity Graph ----
SS %>% 
  ggplot(aes(x = Salinity,
             y = ECe)) +
  geom_boxplot() +
  geom_jitter() +
  theme_bw() +
  labs(title = "End of Experiment Soil Salinity",
       x = "Salinity Treatment",
       y = "ECe dS/m") +
  facet_wrap(SS$Water_Level)

# What is the average soil salinity (not boxplot)? ----
se <- function(x) sd(x)/sqrt(length(x)) #create a SE function

XbarSoil <- SS %>% 
  group_by(Salinity, Water_Level) %>%
  summarize(SE = se(ECe),
            xbar = mean(ECe))

XbarSoil %>% 
  ggplot(aes(x = Salinity,
             y = xbar)) +
  geom_point(size = 6) +
  geom_errorbar(aes(ymin = xbar - SE,
                    ymax = xbar + SE),
                linewidth = 0.7,
                width = 0) +
  theme_bw() +
  labs(title = "Average end of experiment soil salinity",
       x = "Salinity Treatment",
       y = "ECe dS/m") +
  facet_wrap(XbarSoil$Water_Level)


# Average salinity per pot (mean of top and bottom)
SS <- SS %>% 
  group_by(Seed_Mix, Salinity, Water_Level, Bucket) %>% 
  summarize(ECe = mean(ECe))

# T-tests ----
# Check for normality
hist(SS$ECe) # Not exceedingly normal but look at qqplot

qqnorm(SS$ECe)
qqline(SS$ECe) # Roughly normal.. feel OK to move ahead with t.tests

# Another option to check for normality
SS %>% 
  group_by(Salinity, Water_Level) %>% 
  rstatix::shapiro_test(ECe)

# Mostly normal, maybe with exception of High, Drought. Can run T.tests for fresh,
# medium, consider running mann.whitney for high

with(SS, t.test(ECe[Salinity == "Fresh" & Water_Level == "Drought"],
                ECe[Salinity =="Fresh" & Water_Level == "Saturated"]))

with(SS, t.test(ECe[Salinity == "Medium" & Water_Level == "Drought"],
                ECe[Salinity =="Medium" & Water_Level == "Saturated"]))

with(SS, t.test(ECe[Salinity == "High" & Water_Level == "Drought"],
                ECe[Salinity =="High" & Water_Level == "Saturated"]))

# T tests find no difference in achieved soil salinity across water levels (yay!)
Hgh <- SS %>% 
  filter(Salinity == "High")

wilcox.test(Hgh$ECe ~Hgh$Water_Level)

# Model ----
hist(SS$ECe)
hist(log(SS$ECe))

S <- glmmTMB(ECe ~ Seed_Mix * Salinity * Water_Level,
             family = gaussian(),
             data = SS)

simulateResiduals(S, plot = T) # Not great, try log

## Log model ----
S <- glmmTMB(log(ECe) ~ Seed_Mix * Salinity * Water_Level,
             family = gaussian(),
             data = SS)
simulateResiduals(S, plot = T) # Odd shape, try sqrt
plotResiduals(S, form = SS$Seed_Mix) 
plotResiduals(S, form = SS$Salinity)
plotResiduals(S, form = SS$Water_Level)

## Sqrt model ----
S1 <- glmmTMB(sqrt(ECe) ~ Seed_Mix * Salinity * Water_Level,
             family = gaussian(),
             data = SS)
simulateResiduals(S1, plot = T) # Good
plotResiduals(S1, form = SS$Seed_Mix) 
plotResiduals(S1, form = SS$Salinity)
plotResiduals(S1, form = SS$Water_Level)
# Roughly the same model fit, move ahead with log because it is more interpretable

# Analysis ----
car::Anova(S, type = 3)
# Seed_Mix:Salinity interaction

# Show interaction on plot
emmip(S, Seed_Mix ~ Salinity, CIs = T)
# Some differences exist between seed mixes, but they all follow the same pattern
# And we appear to have achieved different salinity levels between fresh,
# med, and high for each seed mix.
# Check on response scale
emmip(S, Seed_Mix ~ Salinity, CIs = T, type = "response")

# Check to see if each seed mix is different between fresh, medium, high
(emm1 <- emmeans(S,
        pairwise ~ Salinity | Seed_Mix,
        adjust = "tukey"))
# Yes they are
emm1mean <- emmeans(S,
                    pairwise ~ Salinity | Seed_Mix,
                    type = "response",
                    adjust = "tukey")

# Are there differences in achieved salinity between seed mixes at each level?
(emm2 <- emmeans(S,
        pairwise ~ Seed_Mix | Salinity,
        adjust = "tukey"))
# Only at freshwater (where no salinity was applied.. so no)

(emm2mean <- emmeans(S,
                 pairwise ~ Seed_Mix | Salinity,
                 type = "response",
                 adjust = "tukey"))

# Create table of ANODEV ----
S_an <- as.data.frame(car::Anova(S, type = 3))
S_an 
colnames(S_an )

# Change header names
S_an <- S_an %>% 
  rownames_to_column(var = ".") %>% 
  rename(Pr = "Pr(>Chisq)")

# Round table values
S_an <- S_an %>% 
  mutate(Pr = P.round(Pr),
         Chisq = FTChi.round(Chisq))

# Make table
S_ANODEV <- flextable(data = S_an) %>% 
  hline(i = NULL, 
        part = "header", 
        border = fp_border(color = "black", 
                           width = 2.0, 
                           style = "solid")) %>% 
  hline_bottom(j = NULL, part = "body",
               border = fp_border(color = "black", 
                                  width = 2.0, 
                                  style = "solid"))
S_ANODEV
setwd("../Output")  
save_as_docx(S_ANODEV, path = "Table_S_ANODEV.docx", 
             pr_section = 
               prop_section(page_size = page_size(orient = "portrait"), 
                            type = "continuous"))  

# Save Model Objects ----
setwd("../Processed_Data")
save(S, SS, emm1, emm2, emm1mean, emm2mean, file = "Model-Objects_Salinity.RData")
