# In this script I take the raw .csv biomass file and process it for future
# analysis for the Mesocosm 2023 experiment

library(tidyverse)

# Load "Mesocosm_Biomass.csv" file
# set your working directory
setwd()
Bio <- read.csv("Mesocosm_Biomass.csv", header = T)
head(Bio)

# Load "Mesocosm_Treatment_Locations.csv" file
Tmt <- read.csv("Mesocosm_Treatment_Locations.csv", header = T)
head(Tmt)

# Check notes
unique(Bio$Notes)
# Notes indicate we can combine buckets and species with >1 harvest bag

# Change into the same units
Bio <- Bio %>% 
  mutate(Weight = case_when(Units == "mg" ~ Weight / 1000,
                            Units == "g" ~ Weight),
         Units = case_when(Units == "mg" ~ "g",
                           Units == "g" ~ Units))
head(Bio)
unique(Bio$Units)

# Sum together any harvests that were more than 1 bag
Bio <- Bio %>% 
  group_by(Bucket, Species, Units) %>% 
  summarize(Weight = sum(Weight)) %>% 
  ungroup()
# 441 to 438 obs.

# Add treatment info
Tmt <- Tmt %>% 
  mutate(Bucket = paste0(Pool, Split_Pool))
head(Tmt)

Bio <- Bio %>% 
  left_join(Tmt, by = "Bucket")

head(Bio)

# Rearrange columns
Bio <- Bio %>% 
  select(Bucket, Pool, Split_Pool, Seed_Mix:Salinity, Species, Weight, Units)

head(Bio)

# Change classes as needed
sapply(Bio, class)

facvec <- c("Bucket", "Pool", "Split_Pool", "Seed_Mix", "Water_Level", "Salinity",
            "Species")
Bio[facvec] <- lapply(Bio[facvec], as.factor)

sapply(Bio, class)

# Each treatment should have 4 reps. I believe each pool grew something, so we
# should have at least 1 harvest bag for each treatment.

# Checking if each bucket had at least 1 harvest
table(Bio$Bucket)

# Checking for 4 reps
Bio %>% 
  group_by(Pool, Split_Pool, Seed_Mix, Water_Level, Salinity) %>% 
  # sum all species
  summarize(Weight = sum(Weight)) %>% 
  ungroup() %>% 
  group_by(Seed_Mix, Water_Level, Salinity) %>% 
  summarize(n = n())
# Yes they all have 4.

# Check min and max of weights ----
min(Bio$Weight)
max(Bio$Weight)

sapply(Bio, levels)

# Correct ordering of salinity levels
Bio <- Bio %>% 
  mutate(Salinity = factor(Salinity, levels = c("Med", "High")),
         Water_Level = case_when(Water_Level == "Saturated" ~ "Moist",
                                 Water_Level == "Drought" ~ "Drought",
                                 TRUE ~ Water_Level), # leave typos as is
         Water_Level = factor(Water_Level, levels = c("Moist", "Drought")))
sapply(Bio, levels)

# Save file
setwd("../Processed_Data")

save(Bio, file = "DF_Biomass.RData")
list.files()
  
  
