# In this script I take the raw .csv percent cover file and process it for future
# analysis for the Mesocosm 2023 experiment

library(tidyverse)

# Set your working directory
setwd()

# Load "Mesocosm_Percent_Cover.csv" file
PC <- read.csv("Mesocosm_Percent_Cover.csv", header = T)

# Load "Mesocosm_Treatment_Locations.csv" file
Tmt <- read.csv("Mesocosm_Treatment_Locations.csv", header = T)

# Go long instead of wide
PC <- PC %>% 
  pivot_longer(cols = BOMA:PHAU, names_to = "Species", values_to = "Cover") %>% 
  rowwise() %>%
  mutate(Soil_Moisture = mean(c_across(starts_with("Soil")), na.rm = TRUE)) %>%
  ungroup() %>% 
  # Remove duplicated cols now
  select(-c(Soil.Moisture:Soil.Moisture.4)) %>% 
  # omit any species with NAs (didn't grow in seed mix)
  na.omit()

# Draw percent cover values to midpoint of cover classes
PC <- PC %>% 
  mutate(Cover = case_when(
           Cover == "0" ~ 0.5,
           Cover == "1" ~ 5.5,
           Cover == "10" ~ 15,
           Cover == "20" ~ 25,
           Cover == "30" ~ 35,
           Cover == "30 " ~ 35,
           Cover == "40" ~ 45,
           Cover == "50" ~ 55,
           Cover == "60" ~ 65,
           Cover == "70" ~ 75,
           Cover == "80" ~ 85,
           Cover == "90" ~ 94.5,
           Cover == "99" ~ 99.5,
           is.na(Cover) ~ 0,
           TRUE ~ Cover),
         Species = case_when(
           Species == "BOMA" ~ "B. maritimus",
           Species == "DISP" ~ "D. spicata",
           Species == "MUAS" ~ "M. asperifolia",
           Species == "PUNU" ~ "P. nuttalliana",
           Species == "SCAC" ~ "S. acutus",
           Species == "ASSP" ~ "A. speciosa",
           Species == "GRSQ" ~ "G. squarrosa",
           Species == "RUMA" ~ "R. maritimus",
           Species == "SARU" ~ "S. rubra",
           Species == "ALOC" ~ "A. occidentalis",
           Species == "BICE" ~ "B. cernua",
           Species == "HEAN" ~ "H. annuus",
           Species == "VEHA" ~ "V. hastata",
           Species == "PHAU" ~ "P. australis",
           TRUE ~ Species))

# Check for any typos
unique(PC$Species)
unique(PC$Cover)

# Left join treatment info
PC <- PC %>% 
  left_join(Tmt, by = c("Pool" = "Pool", "X" = "Split_Pool"))

colnames(PC)
# Remove unneeded columns

PC <- PC %>% 
  select(-c(Recorder, Tmt, Column)) %>% 
  rename("Split_Pool" = "X")

# Check that each treatment had 4 reps, by summing invasive and native cover
PC %>% 
  mutate(Status = case_when(Species == "P. australis" ~ "Invasive",
                            Species != "P. australis" ~ "Native")) %>% 
  group_by(Pool, Split_Pool, Status, Seed_Mix, Salinity,
           Water_Level) %>% 
  summarize(Total_Cover = sum(Cover)) %>% 
  ungroup() %>% 
  group_by(Seed_Mix, Salinity, Water_Level, Status) %>% 
  summarize(n = n()) %>% 
  print(n = 28)

# Yes, all have 4 reps

min(PC$Cover)
max(PC$Cover)

# Check class of columns
sapply(PC, class)

facvec <- c("Pool", "Split_Pool", "Species", "Seed_Mix", "Water_Level", 
            "Salinity")
PC[facvec] <- lapply(PC[facvec], as.factor)
PC <- PC %>% 
  mutate(Date = mdy(Date))

sapply(PC, class)  

# Add status column for easier summing of natives & invasives later.
# Also rearrange column order

PC <- PC %>% 
  mutate(Status = case_when(Species == "P. australis" ~ "Invasive",
                            Species != "P. australis" ~ "Native")) %>% 
  select(Date, Pool, Split_Pool, Seed_Mix, Water_Level, Salinity, Species, Cover,
         Status, Soil_Moisture, Notes)

sapply(PC, levels)
# Correct ordering of salinity levels
PC <- PC %>% 
  mutate(Salinity = factor(Salinity, levels = c("Med", "High")),
         Water_Level = case_when(Water_Level == "Saturated" ~ "Moist",
                                 Water_Level == "Drought" ~ "Drought",
                                 TRUE ~ Water_Level), # Leave any typos as is
         Water_Level = factor(Water_Level, levels = c("Moist", "Drought")))
sapply(PC, levels)

# Save file ----
setwd("../Processed_Data")
save(PC, file = "DF_Percent-Cover.RData")

