# In this script we analyze the Phragmites biomass from the 
# 2023 Mesocosm experiment

# Load packages ----
library(tidyverse)
library(DHARMa)
library(glmmTMB)
library(emmeans)
library(flextable)
library(officer)

# Set contrasts
options(contrasts = c("contr.sum", "contr.poly")) 

# Load Data ----
# Set your working directory to where you saved the processed data frame
setwd()
list.files()
load("DF_Biomass.RData")
head(Bio)

# Data Wrangle ----
Bio <- Bio %>% 
  filter(Species == "PHAU") %>% 
  group_by(Pool, Split_Pool, Seed_Mix, Water_Level, Salinity) %>% 
  summarize(Total_Weight = sum(Weight)) %>% 
  ungroup()

# Re-factor to remove native mixes as a seed mix level

Bio <- Bio %>% 
  mutate(Seed_Mix = factor(Seed_Mix))

sapply(Bio, levels)

# Visualize data ----
Bio %>% 
  ggplot(aes(x = Water_Level,
             y = Total_Weight, 
             fill = Salinity)) +
  geom_boxplot() +
  facet_wrap( ~ Seed_Mix) +
  labs(title = "Raw Total Phragmites Cover",
       x = "Water Condition",
       y = "Total Percent Cover") +
  scale_fill_brewer(palette = "RdYlBu",
                    direction = -1) +
  theme_bw()

# Look at histogram of Bio
hist(Bio$Total_Weight)
hist(log(Bio$Total_Weight)) # Likely will have to log

min(Bio$Total_Weight) # We have no zeroes in this dataset, so we can log if needed
max(Bio$Total_Weight)


# 'Pseudo pool' level = Seed_Mix (3 levels), Water (2 levels), Salinity (3 levs)
# Due to pool constraints we analyze our two native mixes with Phrag as if they were
# sown in independent pools, despite being sown in split-pools

# Normal Model ----

IB <- glmmTMB(Total_Weight ~ Seed_Mix * Salinity * Water_Level,
               data = Bio,
               family = gaussian())

# Inspect model and model assumptions
summary(IB)
IB.resid <- simulateResiduals(IB, plot = T)
# Very poor model fit, move to log transformation (as suspected)



# Normal Log Model ----
IBlog <- glmmTMB(log(Total_Weight) ~ Seed_Mix * Salinity * Water_Level,
                 data = Bio,
                 family = gaussian())

IBlog.resid <- simulateResiduals(IBlog, plot = T)
# Looks good

plotResiduals(IBlog, form = Bio$Water_Level)
plotResiduals(IBlog, form = Bio$Salinity)
plotResiduals(IBlog, form = Bio$Seed_Mix)


# Analysis ----

## ANOVA ----
car::Anova(IBlog, type = 3)
# Seed_Mix:Water_Level 0.038 *
# Salinity:Water_Level 0.012 *

emmip(IBlog, Seed_Mix ~ Salinity, CIs = T) 
# No effect of salinity on total invasive cover

emmip(IBlog, Salinity ~ Water_Level, CIs = T) 
# BUT at interactions of high stress (drought, high), invasive cover is reduced

emmip(IBlog, Seed_Mix ~ Water_Level, CIs = T) 
emmip(IBlog, Seed_Mix ~ Water_Level, CIs = T, type = "response") 
# Drought reduces phragmites cover
# Phragmites cover lower when sown with native species


## 2-way Pairwise comparisons ----

## Seed_Mix:Water_Level ----

# Within water level
emm1 <- emmeans(IBlog, pairwise ~ Seed_Mix | Water_Level, 
                type = "response",
                adjust = "tukey")
emm1

# across water level
emm2 <- emmeans(IBlog, pairwise ~ Water_Level | Seed_Mix, 
                type = "response",
                adjust = "tukey")
emm2


# Might not need these pairwise comparisons. Just a graph probably would suffice

## Salinity:water_level ----

# Salinity:Water_Level interaction (0.0127)
emmip(IBlog, Water_Level ~ Salinity, CIs = T) 
# Under multiple stressors (high salinity, drought), the effect on biomass was 
# greater
# But drought was also just a lot lower than saturated.


# Save model objects ----
# To be used for graphs and figures
setwd("../Processed_Data")
save(IBlog, Bio, emm1, emm2, file = "Model-Objects_IB.RData")

# Save ANODEV table ----
## Source rounding functions, created in a separate script ----
getwd()
setwd("../")
list.files()
source("Function_round.R")

# Create table of ANODEV
IB_an <- as.data.frame(car::Anova(IBlog, type = 3))
IB_an
colnames(IB_an)

# Change header names
IB_an <- IB_an %>% 
  rownames_to_column(var = ".") %>% 
  rename(Pr = "Pr(>Chisq)")

# Round table values  
IB_an <- IB_an %>% 
  mutate(Pr = P.round(Pr),
         Chisq = FTChi.round(Chisq))

# Make table
IB_ANODEV <- flextable(data = IB_an) %>% 
  hline(i = NULL, 
        part = "header", 
        border = fp_border(color = "black", 
                           width = 2.0, 
                           style = "solid")) %>% 
  hline_bottom(j = NULL, part = "body",
               border = fp_border(color = "black", 
                                  width = 2.0, 
                                  style = "solid")) %>% 
  align(j = 2:4, align = "right", part = "header") %>% 
  align(j = 2:4, align = "right", part = "body")

IB_ANODEV
setwd("./Output")  
save_as_docx(IB_ANODEV, path = "Table_IB_ANODEV.docx", 
             pr_section = 
               prop_section(page_size = page_size(orient = "portrait"), 
                            type = "continuous"))  


