# In this script I analyze the native biomass from the 2023 Mesocosm experiment

# Load packages ----
library(tidyverse)
library(DHARMa)
library(glmmTMB)
library(emmeans)
library(officer)
library(flextable)

# Set contrasts
options(contrasts = c("contr.sum", "contr.poly")) 

# Load Data ----
# Set your working directory to where you saved the processed data frame
setwd()
list.files()
load("DF_Biomass.RData")
head(Bio)

# Data Wrangle ----
Bio <- Bio %>% 
  filter(Species != "PHAU") %>% 
  group_by(Pool, Split_Pool, Seed_Mix, Water_Level, Salinity) %>% 
  summarize(Total_Weight = sum(Weight)) %>% 
  ungroup() %>% 
  # Add a coding factor for presence/absence of phrag (assigned at pool level)
  mutate(Phau = as.factor(case_when(Seed_Mix %in% c("Mix 1 with P. australis", 
                                                    "Mix 2 with P. australis") ~ 1,
                                    Seed_Mix %in% c("Mix 1", "Mix 2") ~ 0)),
         # Recode seed mix so that it doesn't overlap with PHAU presence
         Seed_Mix = as.factor(ifelse(str_detect(Seed_Mix, "Mix 1"),
                                     "Mix 1",
                                     ifelse(str_detect(Seed_Mix, "Mix 2"),
                                            "Mix 2",
                                            NA))))

sapply(Bio, levels)
with(Bio, table(Pool))
with(Bio, table(Water_Level))
with(Bio, table(Salinity))
with(Bio, table(Phau))
with(Bio, table(Seed_Mix))

# Visualize data ----
Bio %>% 
  ggplot(aes(x = Water_Level,
             y = Total_Weight, 
             fill = Salinity)) +
  geom_boxplot() +
  facet_wrap( ~ Seed_Mix) +
  labs(title = "Raw total native biomass",
       x = "Water Condition",
       y = "Biomass (g)") +
  scale_fill_brewer(palette = "RdYlBu",
                    direction = -1) +
  theme_bw()
# One outlier in saturated, high, mix 1. Looks like effect of water_level,
# not necessarily salinity

# Look at histogram of Bio
hist(Bio$Total_Weight)
hist(log(Bio$Total_Weight)) # We may need to log our data

min(Bio$Total_Weight) # Not 0, so we can log without changing df

# Model specification ----

# Pool = Water, Salinity, Phrag assigned at pool level
# Half(pool) = Seed_Mix
# 2 x 2 x 2 factorial; seed mix assigned to pool halves, nested in pool

# Normal model ----
NB <- glmmTMB(Total_Weight ~ Water_Level * Salinity * Seed_Mix * Phau
               + (1|Pool),
               family = gaussian(),
               data = Bio)
summary(NB)
simulateResiduals(NB, plot = T)
# Poor model fit


# Normal Log model ----
NBlog <- glmmTMB(log(Total_Weight) ~ Water_Level * Salinity * Seed_Mix * Phau
              + (1|Pool),
              family = gaussian(),
              data = Bio)
summary(NBlog)
simulateResiduals(NBlog, plot = T)
# That's an improvement.
# Plot residuals
plotResiduals(NBlog, form = Bio$Water_Level)
plotResiduals(NBlog, form = Bio$Salinity) # Homogeneity signif different
plotResiduals(NBlog, form = Bio$Phau)
plotResiduals(NBlog, form = Bio$Seed_Mix)


# Also check sqrt model (which we used for our native percent cover)

# Sqrt Normal Model ----
NBsqrt <- glmmTMB(sqrt(Total_Weight) ~ Water_Level * Salinity * Seed_Mix * Phau
                 + (1|Pool),
                 family = gaussian(),
                 data = Bio)
summary(NBsqrt)
simulateResiduals(NBsqrt, plot = T)

# Plot residuals
plotResiduals(NBsqrt, form = Bio$Water_Level)
plotResiduals(NBsqrt, form = Bio$Salinity) # Homogeneity signif different
plotResiduals(NBsqrt, form = Bio$Phau)     # Homogeneity signif different
plotResiduals(NBsqrt, form = Bio$Seed_Mix)
# Log model looks a little better overall


# Could try allowing dispersion parameter to vary by salinity to address
# homogeneity of variance issue with seed mix

# Normal Log model DISP ~Salinity ----
NBlog1 <- glmmTMB(log(Total_Weight) ~ Water_Level * Salinity * Seed_Mix * Phau
                 + (1|Pool),
                 dispformula = ~Salinity,
                 family = gaussian(),
                 data = Bio)
summary(NBlog1)
simulateResiduals(NBlog1, plot = T)
# Might be worse than our normal log model

# Plot residuals
plotResiduals(NBlog1, form = Bio$Water_Level)
plotResiduals(NBlog1, form = Bio$Salinity)
plotResiduals(NBlog1, form = Bio$Phau)     # Homogeneity signif different
plotResiduals(NBlog1, form = Bio$Seed_Mix) # Homogeneity signif different

# This did not address our issue, so we move forward with normal log model without
# disp formula


# Anova ----
summary(NBlog)
car::Anova(NBlog, type = 3)
# Water_Level, Salinity, Seed_Mix main effects significant, but not presence
# of PHAU, and no interactions

# Pairwise comparisons (only 2 levels ea)
emmeans(NBlog, ~ Water_Level)
emmeans(NBlog, ~ Seed_Mix)
emmeans(NBlog, ~ Salinity)
# Salinity pairwise comparisons show p-val of 0.0527
# Salinity was marginal in the Anova (0.046)


# Visualize data with respect to significant results
Bio %>% 
  ggplot(aes(x = Salinity,
             y = Total_Weight, 
             fill = Seed_Mix)) +
  geom_boxplot() +
  labs(title = "Raw total native biomass",
       x = "Water Level",
       y = "Biomass (g)") +
  scale_fill_brewer(palette = "RdYlBu",
                    direction = -1) +
  facet_wrap(~ Water_Level) +
  theme_bw()


## Create emm objects for figures ----
# We do not perform pairwise comparisons, because each main effect has only 2 levels
# and we know they are statistically significantly different due to ANOVA output
emmw <- emmeans(NBlog,  ~ Water_Level,
                type = "response")
emmm <- emmeans(NBlog,  ~ Seed_Mix,
                type = "response")
emms <- emmeans(NBlog,  ~ Salinity,
                type = "response")


# Save model objects ----
# To be used for graphs and figures
setwd("../Processed_Data")
save(NBlog, Bio, emmw, emmm, emms, file = "Model-Objects_NB.RData")

# Save ANODEV table ----
## Source rounding functions, created in a separate script ----
getwd()
setwd("../")
list.files()
source("Function_round.R")

# Create table of ANODEV
NB_an <- as.data.frame(car::Anova(NBlog, type = 3))
NB_an
colnames(NB_an)

# Change header names
NB_an <- NB_an %>% 
  rownames_to_column(var = ".") %>% 
  rename(Pr = "Pr(>Chisq)")

# Round table values
NB_an <- NB_an %>% 
  mutate(Pr = P.round(Pr),
         Chisq = FTChi.round(Chisq))

# Make table
NB_ANODEV <- flextable(data = NB_an) %>% 
  hline(part = "header", 
        border = fp_border(color = "black", 
                           width = 2.0, 
                           style = "solid")) %>% 
  hline_bottom(part = "body",
               border = fp_border(color = "black", 
                                  width = 2.0, 
                                  style = "solid")) %>% 
  align(j = 2:4, align = "right", part = "header") %>% 
  align(j = 2:4, align = "right", part = "body")

NB_ANODEV
setwd("./Output")  
save_as_docx(NB_ANODEV, path = "Table_NB_ANODEV.docx", 
             pr_section = 
               prop_section(page_size = page_size(orient = "portrait"), 
                            type = "continuous"))
