# In this script we analyze the Phragmites percent cover from the 
# 2023 Mesocosm experiment

# Load packages ----
library(tidyverse)
library(DHARMa)
library(glmmTMB)
library(emmeans)
library(officer)
library(flextable)

# Set contrasts
options(contrasts = c("contr.sum", "contr.poly"))

# Load Data ----
# Set your working directory to where you saved the processed data frame
setwd()
list.files()
load("DF_Percent-Cover.RData")

head(PC)

# Data Wrangle ----
PC <- PC %>% 
  filter(Status == "Invasive") %>% 
  filter(Date == max(Date)) %>% 
  group_by(Date, Pool, Split_Pool, Seed_Mix, Water_Level, Salinity) %>% 
  summarize(Total_Cover = sum(Cover)) %>% 
  ungroup()

# Re-factor to remove native mixes as a seed mix level

PC <- PC %>% 
  mutate(Seed_Mix = factor(Seed_Mix))

sapply(PC, levels)

# Visualize data ----
PC %>% 
  ggplot(aes(x = Water_Level,
             y = Total_Cover, 
             fill = Salinity)) +
  geom_boxplot() +
  facet_wrap( ~ Seed_Mix) +
  labs(title = "Raw Total Phragmites Cover",
       x = "Water Condition",
       y = "Total Percent Cover") +
  scale_fill_brewer(palette = "RdYlBu",
                    direction = -1) +
  theme_bw()

# Seed mix effect, water level effect, maybe not a salinity effect?

# Look at histogram of PC
hist(PC$Total_Cover)
hist(log(PC$Total_Cover))

min(PC$Total_Cover) # We have no zeroes in this dataset, so we can log if needed

# 'Pseudo pool' level = Seed_Mix (3 levels), Water (2 levels), Salinity (3 levs)
# Due to pool constraints we analyze our two native mixes with Phrag as if they were
# sown in independent pools, despite being sown in split-pools


# Normal Model ----
IPC <- glmmTMB(Total_Cover ~ Seed_Mix * Salinity * Water_Level,
               data = PC,
               family = gaussian())

# Inspect model and model assumptions
summary(IPC)

IPC.resid <- simulateResiduals(IPC, plot = T)
# Poor fit

plotResiduals(IPC, form = PC$Water_Level)
plotResiduals(IPC, form = PC$Salinity)
plotResiduals(IPC, form = PC$Seed_Mix)
# We could try logging to see if it improves model fit


# Normal Log Model ----
IPClog <- glmmTMB(log(Total_Cover) ~ Seed_Mix * Salinity * Water_Level,
               data = PC,
               family = gaussian())

# Inspect model fit
IPClog.resid <- simulateResiduals(IPClog, plot = T)
plotResiduals(IPClog, form = PC$Water_Level)
plotResiduals(IPClog, form = PC$Salinity)
plotResiduals(IPClog, form = PC$Seed_Mix)
# That does look better, except for homogeneity of variance significant for seed mix
# Which needs addressing


# Sqrt model ----
IPC.sqrt <- glmmTMB(sqrt(Total_Cover) ~ Seed_Mix * Salinity * Water_Level,
                  data = PC,
                  family = gaussian())

simulateResiduals(IPC.sqrt, plot = T)
# Patterning on QQplot residuals

plotResiduals(IPC.sqrt, form = PC$Water_Level)
plotResiduals(IPC.sqrt, form = PC$Salinity)
plotResiduals(IPC.sqrt, form = PC$Seed_Mix)
# These look decent


# Normal Log ~DISP----
# Allow seed mix dispersion values to vary
IPClog2 <- glmmTMB(log(Total_Cover) ~ Seed_Mix * Salinity * Water_Level,
               data = PC,
               dispformula = ~Seed_Mix, # Chosen b/c of plotResiduals from IPClog
               family = gaussian())

IPClog2.resid <- simulateResiduals(IPClog2, plot = T)
# looks better than IPClog

plotResiduals(IPClog2, form = PC$Water_Level)
plotResiduals(IPClog2, form = PC$Salinity)
plotResiduals(IPClog2, form = PC$Seed_Mix)

# This looks like a good model, but we can compare AIC and AICc values
# Original model to dispformula ~Seed Mix

AIC(IPClog, IPClog2) # IPC 2 appears to be a better fit

# Compare also AICc values
AICcmodavg::AICc(IPClog); AICcmodavg::AICc(IPClog, return.K = T)
AICcmodavg::AICc(IPClog2); AICcmodavg::AICc(IPClog2, return.K = T)
# IPC2 which allows for a dispersion parameter to vary based on seed mix appears
# to be the better fitting model


# Sqrt vs IPClog2 model
simulateResiduals(IPC.sqrt, plot = T)
simulateResiduals(IPClog2, plot = T)
# The patterning in IPC.sqrt is not ideal, so we move forward with IPClog2


# Anova ----
car::Anova(IPClog2, type = 3)
# No 3-way 
# Seed_Mix:Salinity    = 0.031
# Seed_Mix:Water_Level = 0.053 (weak effect)

emmip(IPClog2, Seed_Mix ~ Salinity, CIs = T, type = "response") 
# Mix 2 had higher invasive cover at high salinity, a result of noise?
# Differences not that large on model scale.
# And we know that averaged over seed mix we don't have an effect of salinity
# (main effect salinity not significant)

# Examine multiple comparisons within seed mix for salinity to see effects
emmeans(IPClog2, pairwise ~ Salinity | Seed_Mix, 
        type = "response",
        adjust = "tukey")
# Mix 2 only one different, likely driven by outlier, ratio only 0.337, so small
# difference: address outlier briefly in results, but display water differences


emmip(IPClog2, Seed_Mix ~ Water_Level, CIs = T) 
emmip(IPClog2, Seed_Mix ~ Water_Level, CIs = T, type = "response") 

# Pairwise comparisons ----

# Seed_Mix:Water_Level

# Across water level
emm1 <- emmeans(IPClog2, pairwise ~ Water_Level | Seed_Mix,
                type = "response",
                adjust = "tukey")
emm1
# They are all reduced by drought

# Within water level (across seed mix)
emm2 <- emmeans(IPClog2, pairwise ~ Seed_Mix | Water_Level,
                type = "response",
                adjust = "tukey")
emm2
# Native mixes are the same, P. australis different.


# Save model objects ----
# To be used for graphs and figures
setwd("../Processed_Data")
save(IPClog2, PC, emm1, emm2, file = "Model-Objects_IPC.RData")


# Save ANODEV table ----
## Source rounding functions, created in a separate script ----
getwd()
setwd("../")
list.files()
source("Function_round.R")

# Create table of ANODEV
IC_an <- as.data.frame(car::Anova(IPClog2, type = 3))
IC_an
colnames(IC_an)

# Change header names
IC_an <- IC_an %>% 
  rownames_to_column(var = ".") %>% 
  rename(Pr = "Pr(>Chisq)")

# Round table values
IC_an <- IC_an %>% 
  mutate(Pr = P.round(Pr),
         Chisq = FTChi.round(Chisq))

# Make table
IC_ANODEV <- flextable(data = IC_an) %>% 
  hline(i = NULL, 
        part = "header", 
        border = fp_border(color = "black", 
                           width = 2.0, 
                           style = "solid")) %>% 
  hline_bottom(j = NULL, part = "body",
               border = fp_border(color = "black", 
                                  width = 2.0, 
                                  style = "solid")) %>% 
  align(j = 2:4, align = "right", part = "header") %>% 
  align(j = 2:4, align = "right", part = "body")

IC_ANODEV
setwd("./Output")  
save_as_docx(IC_ANODEV, path = "Table_IC_ANODEV.docx", 
             pr_section = 
               prop_section(page_size = page_size(orient = "portrait"), 
                            type = "continuous"))  
