# In this script I analyze the native percent cover for the Mesocosm 2023 exp.

# Load packages ----
library(tidyverse)
library(DHARMa)
library(glmmTMB)
library(emmeans)
library(flextable)
library(officer)

# Set contrasts
options(contrasts = c("contr.sum", "contr.poly")) 

# Load Data ----
# Set your working directory to where you saved the processed data frame
setwd()
list.files()
load("DF_Percent-Cover.RData")

head(PC)

# Sum all natives within each pool and split pool

# Data Wrangle ----
PC <- PC %>% 
  filter(Status == "Native") %>% 
  filter(Date == max(Date)) %>% 
  group_by(Date, Pool, Split_Pool, Seed_Mix, Water_Level, Salinity) %>% 
  summarize(Total_Cover = sum(Cover)) %>% 
  ungroup() %>% 
  # Add a coding factor for presence/absence of phrag (assigned at pool level)
  mutate(Phau = as.factor(case_when(Seed_Mix %in% c("Mix 1 with P. australis", 
                                          "Mix 2 with P. australis") ~ 1,
                          Seed_Mix %in% c("Mix 1", "Mix 2") ~ 0)),
  # Recode seed mix so that it doesn't overlap with PHAU presence
         Seed_Mix = as.factor(ifelse(str_detect(Seed_Mix, "Mix 1"),
                                     "Mix 1",
                                     ifelse(str_detect(Seed_Mix, "Mix 2"),
                                            "Mix 2",
                                            NA))),
   Pool = factor(Pool))


sapply(PC, levels)
with(PC, table(Pool))
with(PC, table(Water_Level))
with(PC, table(Salinity))
with(PC, table(Phau))
with(PC, table(Seed_Mix))

# Visualize data ----
PC %>% 
ggplot(aes(x = Water_Level,
           y = Total_Cover, 
           fill = Salinity)) +
  geom_boxplot() +
  facet_wrap( ~ Seed_Mix) +
  labs(title = "Raw total native cover",
       x = "Water Level",
       y = "Total percent cover") +
  scale_fill_brewer(palette = "RdYlBu",
                    direction = -1) +
  theme_bw()
# Water level looks like it affected seed mix, but salinity not too different

# Look at histogram of PC
hist(PC$Total_Cover)
hist(log(PC$Total_Cover))

min(PC$Total_Cover) # We have no zeroes in this dataset, so we can log if needed

# Model specification ----

  # Pool = Water, Salinity, Phrag assigned at pool level
  # Half-pool = Seed_Mix
  # 2 x 2 x 2 factorial; seed mix assigned to pool halves, nested in pool

# Normal model ----
NPC <- glmmTMB(Total_Cover ~ Water_Level * Salinity * Seed_Mix * Phau
               + (1|Pool),
               family = gaussian(),
               data = PC)
summary(NPC)
simulateResiduals(NPC, plot = T)
# Looks OK. 
plotResiduals(NPC, form = PC$Water_Level) # homogeneity of variance significant
plotResiduals(NPC, form = PC$Salinity)
plotResiduals(NPC, form = PC$Phau)
plotResiduals(NPC, form = PC$Seed_Mix)


# Sqrt model ----
NPC.sqrt <- glmmTMB(sqrt(Total_Cover) ~ Water_Level * Salinity * Seed_Mix * Phau 
                    + (1|Pool),
                    family = gaussian(),
                    data = PC)
summary(NPC.sqrt)
simulateResiduals(NPC.sqrt, plot = T)
# Maybe better

plotResiduals(NPC.sqrt, form = PC$Water_Level)
plotResiduals(NPC.sqrt, form = PC$Salinity)
plotResiduals(NPC.sqrt, form = PC$Phau)
plotResiduals(NPC.sqrt, form = PC$Seed_Mix)
# All look good

# Normal Log DISPformula ~ Water_Level
NPC1 <- glmmTMB(Total_Cover ~ Water_Level * Salinity * Seed_Mix * Phau
               + (1|Pool),
               dispformula = ~Water_Level,
               family = gaussian(),
               data = PC)
summary(NPC1)
simulateResiduals(NPC1, plot = T)
# Looks OK. 
plotResiduals(NPC1, form = PC$Water_Level)
plotResiduals(NPC1, form = PC$Salinity)
plotResiduals(NPC1, form = PC$Phau)
plotResiduals(NPC1, form = PC$Seed_Mix)

AIC(NPC, NPC1)
AICcmodavg::AICc(NPC); AICcmodavg::AICc(NPC, return.K = T)
AICcmodavg::AICc(NPC1); AICcmodavg::AICc(NPC1, return.K = T)
# NPC1 (dispformula ~Water_Level) is a better fitting modelthan simply logged.
# But sqrt model is equally as well-fitting without having to use dispformula
# So we move ahead with that.

# ANOVA ----
summary(NPC.sqrt)
car::Anova(NPC.sqrt, type = 3)
# Only main effects Seed_Mix and Water_Level are significant,
# salinity and presence of PHAU had no effect, and no interactions

# Visualize model data ----
test <- emmeans(NPC.sqrt, ~ Water_Level * Salinity * Seed_Mix * Phau,
        type = "response")
test <- as.data.frame(test)
test %>% 
ggplot(aes(x = Salinity,
           y = response)) +
  geom_jitter(aes(color = interaction(Seed_Mix, Water_Level)),
              size = 4,
              position = position_dodge(width = 0.4)) +
  geom_line(aes(group = interaction(Seed_Mix, Water_Level)),
            linewidth = 0.7,
            linetype = "dotted",
            position = position_dodge(width = 0.4)) +
  geom_errorbar(aes(ymin = response - SE,
                    ymax = response + SE,
                    color = interaction(Seed_Mix, Water_Level)),
                width = 0, linewidth = 1,
                position = position_dodge(width = 0.4)) +
  facet_wrap( ~ Phau) +
  labs(title = "Raw total native cover",
       x = "Water Level",
       y = "Total percent cover") +
  scale_fill_brewer(palette = "RdYlBu",
                    direction = -1) +
  scale_color_manual(values = c("lightblue1", "lightgreen", "blue1", "green3")) +
  theme_bw()

# Trends look the same: seed mix effect, water effect, no salinity
# With the exception of mix 2 moist, does presence of PHAU matter?
emmeans(NPC.sqrt, pairwise ~ (Phau * Water_Level | Seed_Mix),
        type = "response")
# For each seed mix compare 0 moist to 1 moist, and 0 drought to 1 drought
# No differences -

## Create emm objects for figures ----
# Both main effects have only two levels, so we don't need to perform pairwise
# comparisons, because ANOVA tells us the two levels are statistically different
emmw <- emmeans(NPC.sqrt, ~ Water_Level,
        type = "response")
emmm <- emmeans(NPC.sqrt, ~ Seed_Mix,
        type = "response")


# Save model objects ----
# To be used for graphs and figures
setwd("../Processed_Data")
save(NPC.sqrt, PC, emmw, emmm, file = "Model-Objects_NPC.RData")

# Save ANODEV table ----
## Source rounding functions, created in a separate script ----
getwd()
setwd("../")
list.files()
source("Function_round.R")

# Create table of ANODEV
NC_an <- as.data.frame(car::Anova(NPC.sqrt, type = 3))
NC_an
colnames(NC_an)

# Change header names
NC_an <- NC_an %>% 
  rownames_to_column(var = ".") %>% 
  rename(Pr = "Pr(>Chisq)")

# Round table values
NC_an <- NC_an %>% 
  mutate(Pr = P.round(Pr),
         Chisq = FTChi.round(Chisq))

# Make table
NC_ANODEV <- flextable(data = NC_an) %>% 
  hline(part = "header", 
        border = fp_border(color = "black", 
                           width = 2.0, 
                           style = "solid")) %>% 
  hline_bottom(part = "body",
               border = fp_border(color = "black", 
                                  width = 2.0, 
                                  style = "solid")) %>% 
  align(j = 2:4, align = "right", part = "header") %>% 
  align(j = 2:4, align = "right", part = "body")
  
NC_ANODEV
setwd("./Output")  
save_as_docx(NC_ANODEV, path = "Table_NC_ANODEV.docx", 
             pr_section = 
               prop_section(page_size = page_size(orient = "portrait"), 
                            type = "continuous"))  
