# In this script we analyze the final soil salinity values 
# from the end of experiment mesocosm experiment

# Load libraries ----
library(tidyverse)
library(glmmTMB)
library(DHARMa)
library(emmeans)
library(officer)
library(flextable)

# Set contrasts, for Type 3 Anova
options(contrasts = c("contr.sum", "contr.poly")) 

# Load data ----
# Set your working directory
setwd()
# load "Mesocosm_Salinity_Soil.csv" file

Sal <- read.csv("Mesocosm_Salinity_Soil.csv", header = T)
head(Sal)

# Data Wrangle ----
Sal <- Sal %>% 
  mutate(Soil.Weight.mL = Soil.Weight.mL / 1000, # Put into grams
         Water.Weight.mL = Water.Weight.mL / 1000) # Put into grams

# Calculate ECe for each sample ----
# ECe = EC 1:5 * (g water added / 70% of soil volume)
Sal <- Sal %>% 
  group_by(Pool, Half.Pool, Position) %>% 
  mutate(ECe = EC.microS.cm * (Water.Weight.mL / (0.70 * Soil.Volume.mL)),
         ECe = ECe / 1000) # Convert to dS / m 

# We can fit a model to see if there were differences in achieved salinity
# between medium and high treatments, accounting for pool as a random effect

# Load treatment info ----
getwd()
list.files()
Tmt <- read.csv("Mesocosm_Treatment_Locations.csv", header = T)
head(Tmt)
head(Sal)
Sal <- Sal %>% 
  rename(Split_Pool = Half.Pool)

Sal <- Sal %>% 
  left_join(Tmt, by = c("Pool", "Split_Pool")) %>% 
  select(Pool, Split_Pool, Position, ECe, Water_Level, Seed_Mix, Salinity) %>% 
  # Put factor levels in desired order
  mutate(Water_Level = factor(Water_Level, levels = c("Saturated", "Drought")),
         Salinity = factor(Salinity, levels = c("Med", "High")))


head(Sal)
sapply(Sal, class)
# Change class to factor
facvec <- c("Water_Level", "Seed_Mix", "Salinity", "Pool", "Split_Pool", 
            "Position")
Sal[facvec] <- lapply(Sal[facvec], as.factor)
sapply(Sal, class)

# Graph raw data ----
# Bottom soil samples only
Sal %>% 
  filter(Position == "B") %>% 
  ggplot(aes(x = Salinity,
             y = ECe)) +
  geom_boxplot() + 
  geom_point() + 
  geom_jitter() +
  facet_wrap( ~ Water_Level)

# Top soil samples only
Sal %>% 
  filter(Position == "T") %>% 
  ggplot(aes(x = Salinity,
             y = ECe)) +
  geom_boxplot() + 
  geom_point() + 
  geom_jitter() +
  facet_wrap( ~ Water_Level)

# Top and bottom
Sal %>% 
  ggplot(aes(x = Salinity,
             y = ECe)) +
  geom_boxplot() + 
  geom_point() + 
  geom_jitter() +
  facet_wrap( ~ Water_Level)


# We will first analyze only native seed mixes (which allows us to use pool
# as a random effect)
# If pool variance is very small, we will then drop pool as a random effect
# and analyze all seed mixes together

# Data Wrangle for Native model ----
N <- Sal %>% 
  # Remove unnecessary seed mixes
  filter(Seed_Mix != "CONTROL" & Seed_Mix != "P. australis") %>% 
  # Add a presence/absence variable for phrag
  mutate(Phau = as.factor(case_when(Seed_Mix %in% c("Mix 1 with P. australis", 
                                                    "Mix 2 with P. australis") ~ 1,
                                    Seed_Mix %in% c("Mix 1", "Mix 2") ~ 0)),
  # Change Seed mix names to mix 1 / mix 2 (since we have PHAU as a sep. variable)
         Seed_Mix = as.factor(ifelse(str_detect(Seed_Mix, "Mix 1"),
                                     "Mix 1",
                                     ifelse(str_detect(Seed_Mix, "Mix 2"),
                                            "Mix 2",
                                            NA))),
         Pool = factor(Pool))

hist(N$ECe)
# We will have to log
min(N$ECe)
hist(log(N$ECe))

sapply(N, levels)
# Check that each split pool has 2 obs (top / bottom)
with(N, table(Pool, Split_Pool)) 
with(N, table(Water_Level)) 
with(N, table(Salinity)) 
with(N, table(Phau))
with(N, table(Seed_Mix))
# All look good

# (Native) Model ----
NM <- glmmTMB(log(ECe) ~ Water_Level * Salinity * Seed_Mix * Phau
             + (1 | Pool),
             family = gaussian(),
             data = N)
# False convergence (8), check a different optimizer

NM1 <- glmmTMB(log(ECe) ~ Water_Level * Salinity * Seed_Mix * Phau
              + (1 | Pool),
              family = gaussian(),
              control=glmmTMBControl(optimizer=optim,
                                     optArgs=list(method="BFGS")),
              data = N)
# That ran, check summary compared to original
(parcomp <- cbind(log = unlist(fixef(NM)),
                  log_optim = unlist(fixef(NM1))))

# Those are almost identical, so we conclude that the false convergence warning
# is a false positive (and we are OK to move forward)
# But we can also check to see hessian curvature of model
NM$sdr$pdHess # It is positive, so we are good to move forward.

# Check model fit
simulateResiduals(NM, plot = T)
# Model looks good
plotResiduals(NM, form = N$Water_Level)
plotResiduals(NM, form = N$Seed_Mix)
plotResiduals(NM, form = N$Salinity)
plotResiduals(NM, form = N$Phau)
# Those all look good

# Examine summary to see if variance in pools is small
summary(NM)
# Pool variance is really tiny (2.742 e -09)
# in comparison to the remaining residual variance (.408)
# Which justifies an analysis where we drop pool as a factor and analyze
# ECe as a function of all seed mixes (a 1 x 6 fixed effect)



# All seed mixes analysis ----
sapply(Sal, levels)
# Check that each split pool has 2 obs (top / bottom)
with(Sal, table(Pool, Split_Pool)) 
with(Sal, table(Water_Level)) 
with(Sal, table(Salinity)) 
with(Sal, table(Seed_Mix))
# All looks good

hist(Sal$ECe)
# We will have to log most likely
min(Sal$ECe)
hist(log(Sal$ECe))

S <- glmmTMB(log(ECe) ~ Water_Level * Salinity * Seed_Mix,
              family = gaussian(),
              data = Sal)
summary(S)
simulateResiduals(S, plot = T)
# Model fit is good
plotResiduals(S, form = Sal$Water_Level)
plotResiduals(S, form = Sal$Seed_Mix)
plotResiduals(S, form = Sal$Salinity)
# Those all look good

## ANOVA
car::Anova(S, type = 3)
# Water_Level : Salinity interaction (0.021)

# Visualize interaction
emmip(S, ~ Salinity | Water_Level, CIs = T, type = "response") 
# Salinity lower in saturated ->
# Plants (presumably) used up a lot of salt at medium level, used  up less at high level
# But comparatively, at drought plants used no salt at either salinity level

emmip(S, ~ Water_Level | Salinity, CIs = T, type = "response") 
# Salinity lower in saturated, presumably because plants grew, and used up salts


## Follow-up pairwise ----
emm1 <- emmeans(S, 
        pairwise ~ Water_Level | Salinity,
        adjust = "tukey",
        type = "response")
emm1
# Salinity higher in drought pools than in saturated pools

emm2 <- emmeans(S, 
        pairwise ~ Salinity | Water_Level,
        adjust = "tukey",
        type = "response")
emm2

means <- emmeans(S, 
                 pairwise ~ Salinity | Water_Level,
                 adjust = "tukey",
                 type = "response")
means <- means$emmeans

# diff b/n med and high for saturated
# No diff in salinity b/n med/high for drought
# I think this indicates that 4 dS/m is close to the original salinity level
# But saturated conditions allowed for plant growth, and end of experiment
# salinity was reduced as a result


# Save model objects ----
# To be used for graphs and figures
setwd("../Processed_Data")
save(emm2, S, means, file = "Model-Objects_Salinity.RData")


# Save ANODEV table ----
## Source rounding functions, created in a separate script ----
getwd()
setwd("../")
list.files()
source("Function_round.R")

# Create table of ANODEV
Sal_an <- as.data.frame(car::Anova(S, type = 3))
Sal_an
colnames(Sal_an)

# Change header names
Sal_an <- Sal_an %>% 
  rownames_to_column(var = ".") %>% 
  rename(Pr = "Pr(>Chisq)")

# Round table values  
Sal_an <- Sal_an %>% 
  mutate(Pr = P.round(Pr),
         Chisq = FTChi.round(Chisq))

# Make table
Sal_ANODEV <- flextable(data = Sal_an) %>% 
  hline(i = NULL, 
        part = "header", 
        border = fp_border(color = "black", 
                           width = 2.0, 
                           style = "solid")) %>% 
  hline_bottom(j = NULL, part = "body",
               border = fp_border(color = "black", 
                                  width = 2.0, 
                                  style = "solid")) %>% 
  align(j = 2:4, align = "right", part = "header") %>% 
  align(j = 2:4, align = "right", part = "body")

Sal_ANODEV
setwd("./Output")  
save_as_docx(Sal_ANODEV, path = "Table_Sal_ANODEV.docx", 
             pr_section = 
               prop_section(page_size = page_size(orient = "portrait"), 
                            type = "continuous"))   
